# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import vectorindex_pb2 as vectorindex__pb2


class VectorIndexStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpsertItemBatch = channel.unary_unary(
                '/vectorindex.VectorIndex/UpsertItemBatch',
                request_serializer=vectorindex__pb2._UpsertItemBatchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._UpsertItemBatchResponse.FromString,
                )
        self.DeleteItemBatch = channel.unary_unary(
                '/vectorindex.VectorIndex/DeleteItemBatch',
                request_serializer=vectorindex__pb2._DeleteItemBatchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._DeleteItemBatchResponse.FromString,
                )
        self.Search = channel.unary_unary(
                '/vectorindex.VectorIndex/Search',
                request_serializer=vectorindex__pb2._SearchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._SearchResponse.FromString,
                )
        self.SearchAndFetchVectors = channel.unary_unary(
                '/vectorindex.VectorIndex/SearchAndFetchVectors',
                request_serializer=vectorindex__pb2._SearchAndFetchVectorsRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._SearchAndFetchVectorsResponse.FromString,
                )
        self.GetItemMetadataBatch = channel.unary_unary(
                '/vectorindex.VectorIndex/GetItemMetadataBatch',
                request_serializer=vectorindex__pb2._GetItemMetadataBatchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._GetItemMetadataBatchResponse.FromString,
                )
        self.GetItemBatch = channel.unary_unary(
                '/vectorindex.VectorIndex/GetItemBatch',
                request_serializer=vectorindex__pb2._GetItemBatchRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._GetItemBatchResponse.FromString,
                )
        self.CountItems = channel.unary_unary(
                '/vectorindex.VectorIndex/CountItems',
                request_serializer=vectorindex__pb2._CountItemsRequest.SerializeToString,
                response_deserializer=vectorindex__pb2._CountItemsResponse.FromString,
                )


class VectorIndexServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UpsertItemBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteItemBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Search(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchAndFetchVectors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetItemMetadataBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetItemBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountItems(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VectorIndexServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpsertItemBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertItemBatch,
                    request_deserializer=vectorindex__pb2._UpsertItemBatchRequest.FromString,
                    response_serializer=vectorindex__pb2._UpsertItemBatchResponse.SerializeToString,
            ),
            'DeleteItemBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteItemBatch,
                    request_deserializer=vectorindex__pb2._DeleteItemBatchRequest.FromString,
                    response_serializer=vectorindex__pb2._DeleteItemBatchResponse.SerializeToString,
            ),
            'Search': grpc.unary_unary_rpc_method_handler(
                    servicer.Search,
                    request_deserializer=vectorindex__pb2._SearchRequest.FromString,
                    response_serializer=vectorindex__pb2._SearchResponse.SerializeToString,
            ),
            'SearchAndFetchVectors': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchAndFetchVectors,
                    request_deserializer=vectorindex__pb2._SearchAndFetchVectorsRequest.FromString,
                    response_serializer=vectorindex__pb2._SearchAndFetchVectorsResponse.SerializeToString,
            ),
            'GetItemMetadataBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetItemMetadataBatch,
                    request_deserializer=vectorindex__pb2._GetItemMetadataBatchRequest.FromString,
                    response_serializer=vectorindex__pb2._GetItemMetadataBatchResponse.SerializeToString,
            ),
            'GetItemBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetItemBatch,
                    request_deserializer=vectorindex__pb2._GetItemBatchRequest.FromString,
                    response_serializer=vectorindex__pb2._GetItemBatchResponse.SerializeToString,
            ),
            'CountItems': grpc.unary_unary_rpc_method_handler(
                    servicer.CountItems,
                    request_deserializer=vectorindex__pb2._CountItemsRequest.FromString,
                    response_serializer=vectorindex__pb2._CountItemsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vectorindex.VectorIndex', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VectorIndex(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UpsertItemBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/UpsertItemBatch',
            vectorindex__pb2._UpsertItemBatchRequest.SerializeToString,
            vectorindex__pb2._UpsertItemBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteItemBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/DeleteItemBatch',
            vectorindex__pb2._DeleteItemBatchRequest.SerializeToString,
            vectorindex__pb2._DeleteItemBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/Search',
            vectorindex__pb2._SearchRequest.SerializeToString,
            vectorindex__pb2._SearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchAndFetchVectors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/SearchAndFetchVectors',
            vectorindex__pb2._SearchAndFetchVectorsRequest.SerializeToString,
            vectorindex__pb2._SearchAndFetchVectorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetItemMetadataBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/GetItemMetadataBatch',
            vectorindex__pb2._GetItemMetadataBatchRequest.SerializeToString,
            vectorindex__pb2._GetItemMetadataBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetItemBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/GetItemBatch',
            vectorindex__pb2._GetItemBatchRequest.SerializeToString,
            vectorindex__pb2._GetItemBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CountItems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/vectorindex.VectorIndex/CountItems',
            vectorindex__pb2._CountItemsRequest.SerializeToString,
            vectorindex__pb2._CountItemsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
