# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: permissionmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18permissionmessages.proto\x12\x13permission_messages\"\x94\x01\n\x0bPermissions\x12?\n\nsuper_user\x18\x01 \x01(\x0e\x32).permission_messages.SuperUserPermissionsH\x00\x12<\n\x08\x65xplicit\x18\x02 \x01(\x0b\x32(.permission_messages.ExplicitPermissionsH\x00\x42\x06\n\x04kind\"P\n\x13\x45xplicitPermissions\x12\x39\n\x0bpermissions\x18\x01 \x03(\x0b\x32$.permission_messages.PermissionsType\"\xee\x08\n\x0fPermissionsType\x12R\n\x11\x63\x61\x63he_permissions\x18\x01 \x01(\x0b\x32\x35.permission_messages.PermissionsType.CachePermissionsH\x00\x12R\n\x11topic_permissions\x18\x02 \x01(\x0b\x32\x35.permission_messages.PermissionsType.TopicPermissionsH\x00\x1a\x05\n\x03\x41ll\x1a-\n\rCacheSelector\x12\x14\n\ncache_name\x18\x01 \x01(\tH\x00\x42\x06\n\x04kind\x1a@\n\x11\x43\x61\x63heItemSelector\x12\r\n\x03key\x18\x01 \x01(\x0cH\x00\x12\x14\n\nkey_prefix\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04kind\x1a\xf5\x02\n\x10\x43\x61\x63hePermissions\x12,\n\x04role\x18\x01 \x01(\x0e\x32\x1e.permission_messages.CacheRole\x12>\n\nall_caches\x18\x02 \x01(\x0b\x32(.permission_messages.PermissionsType.AllH\x00\x12L\n\x0e\x63\x61\x63he_selector\x18\x03 \x01(\x0b\x32\x32.permission_messages.PermissionsType.CacheSelectorH\x00\x12=\n\tall_items\x18\x04 \x01(\x0b\x32(.permission_messages.PermissionsType.AllH\x01\x12O\n\ritem_selector\x18\x05 \x01(\x0b\x32\x36.permission_messages.PermissionsType.CacheItemSelectorH\x01\x42\x07\n\x05\x63\x61\x63heB\x0c\n\ncache_item\x1aJ\n\rTopicSelector\x12\x14\n\ntopic_name\x18\x01 \x01(\tH\x00\x12\x1b\n\x11topic_name_prefix\x18\x02 \x01(\tH\x00\x42\x06\n\x04kind\x1a\xee\x02\n\x10TopicPermissions\x12,\n\x04role\x18\x01 \x01(\x0e\x32\x1e.permission_messages.TopicRole\x12>\n\nall_caches\x18\x02 \x01(\x0b\x32(.permission_messages.PermissionsType.AllH\x00\x12L\n\x0e\x63\x61\x63he_selector\x18\x03 \x01(\x0b\x32\x32.permission_messages.PermissionsType.CacheSelectorH\x00\x12>\n\nall_topics\x18\x04 \x01(\x0b\x32(.permission_messages.PermissionsType.AllH\x01\x12L\n\x0etopic_selector\x18\x05 \x01(\x0b\x32\x32.permission_messages.PermissionsType.TopicSelectorH\x01\x42\x07\n\x05\x63\x61\x63heB\x07\n\x05topicB\x06\n\x04kind*[\n\tCacheRole\x12\x13\n\x0f\x43\x61\x63hePermitNone\x10\x00\x12\x12\n\x0e\x43\x61\x63heReadWrite\x10\x01\x12\x11\n\rCacheReadOnly\x10\x02\x12\x12\n\x0e\x43\x61\x63heWriteOnly\x10\x03*[\n\tTopicRole\x12\x13\n\x0fTopicPermitNone\x10\x00\x12\x12\n\x0eTopicReadWrite\x10\x01\x12\x11\n\rTopicReadOnly\x10\x02\x12\x12\n\x0eTopicWriteOnly\x10\x03*%\n\x14SuperUserPermissions\x12\r\n\tSuperUser\x10\x00\x42r\n\x18grpc.permission_messagesP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02!Momento.Protos.PermissionMessagesb\x06proto3')

_CACHEROLE = DESCRIPTOR.enum_types_by_name['CacheRole']
CacheRole = enum_type_wrapper.EnumTypeWrapper(_CACHEROLE)
_TOPICROLE = DESCRIPTOR.enum_types_by_name['TopicRole']
TopicRole = enum_type_wrapper.EnumTypeWrapper(_TOPICROLE)
_SUPERUSERPERMISSIONS = DESCRIPTOR.enum_types_by_name['SuperUserPermissions']
SuperUserPermissions = enum_type_wrapper.EnumTypeWrapper(_SUPERUSERPERMISSIONS)
CachePermitNone = 0
CacheReadWrite = 1
CacheReadOnly = 2
CacheWriteOnly = 3
TopicPermitNone = 0
TopicReadWrite = 1
TopicReadOnly = 2
TopicWriteOnly = 3
SuperUser = 0


_PERMISSIONS = DESCRIPTOR.message_types_by_name['Permissions']
_EXPLICITPERMISSIONS = DESCRIPTOR.message_types_by_name['ExplicitPermissions']
_PERMISSIONSTYPE = DESCRIPTOR.message_types_by_name['PermissionsType']
_PERMISSIONSTYPE_ALL = _PERMISSIONSTYPE.nested_types_by_name['All']
_PERMISSIONSTYPE_CACHESELECTOR = _PERMISSIONSTYPE.nested_types_by_name['CacheSelector']
_PERMISSIONSTYPE_CACHEITEMSELECTOR = _PERMISSIONSTYPE.nested_types_by_name['CacheItemSelector']
_PERMISSIONSTYPE_CACHEPERMISSIONS = _PERMISSIONSTYPE.nested_types_by_name['CachePermissions']
_PERMISSIONSTYPE_TOPICSELECTOR = _PERMISSIONSTYPE.nested_types_by_name['TopicSelector']
_PERMISSIONSTYPE_TOPICPERMISSIONS = _PERMISSIONSTYPE.nested_types_by_name['TopicPermissions']
Permissions = _reflection.GeneratedProtocolMessageType('Permissions', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONS,
  '__module__' : 'permissionmessages_pb2'
  # @@protoc_insertion_point(class_scope:permission_messages.Permissions)
  })
_sym_db.RegisterMessage(Permissions)

ExplicitPermissions = _reflection.GeneratedProtocolMessageType('ExplicitPermissions', (_message.Message,), {
  'DESCRIPTOR' : _EXPLICITPERMISSIONS,
  '__module__' : 'permissionmessages_pb2'
  # @@protoc_insertion_point(class_scope:permission_messages.ExplicitPermissions)
  })
_sym_db.RegisterMessage(ExplicitPermissions)

PermissionsType = _reflection.GeneratedProtocolMessageType('PermissionsType', (_message.Message,), {

  'All' : _reflection.GeneratedProtocolMessageType('All', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_ALL,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.All)
    })
  ,

  'CacheSelector' : _reflection.GeneratedProtocolMessageType('CacheSelector', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_CACHESELECTOR,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.CacheSelector)
    })
  ,

  'CacheItemSelector' : _reflection.GeneratedProtocolMessageType('CacheItemSelector', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_CACHEITEMSELECTOR,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.CacheItemSelector)
    })
  ,

  'CachePermissions' : _reflection.GeneratedProtocolMessageType('CachePermissions', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_CACHEPERMISSIONS,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.CachePermissions)
    })
  ,

  'TopicSelector' : _reflection.GeneratedProtocolMessageType('TopicSelector', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_TOPICSELECTOR,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.TopicSelector)
    })
  ,

  'TopicPermissions' : _reflection.GeneratedProtocolMessageType('TopicPermissions', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSIONSTYPE_TOPICPERMISSIONS,
    '__module__' : 'permissionmessages_pb2'
    # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType.TopicPermissions)
    })
  ,
  'DESCRIPTOR' : _PERMISSIONSTYPE,
  '__module__' : 'permissionmessages_pb2'
  # @@protoc_insertion_point(class_scope:permission_messages.PermissionsType)
  })
_sym_db.RegisterMessage(PermissionsType)
_sym_db.RegisterMessage(PermissionsType.All)
_sym_db.RegisterMessage(PermissionsType.CacheSelector)
_sym_db.RegisterMessage(PermissionsType.CacheItemSelector)
_sym_db.RegisterMessage(PermissionsType.CachePermissions)
_sym_db.RegisterMessage(PermissionsType.TopicSelector)
_sym_db.RegisterMessage(PermissionsType.TopicPermissions)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030grpc.permission_messagesP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002!Momento.Protos.PermissionMessages'
  _CACHEROLE._serialized_start=1419
  _CACHEROLE._serialized_end=1510
  _TOPICROLE._serialized_start=1512
  _TOPICROLE._serialized_end=1603
  _SUPERUSERPERMISSIONS._serialized_start=1605
  _SUPERUSERPERMISSIONS._serialized_end=1642
  _PERMISSIONS._serialized_start=50
  _PERMISSIONS._serialized_end=198
  _EXPLICITPERMISSIONS._serialized_start=200
  _EXPLICITPERMISSIONS._serialized_end=280
  _PERMISSIONSTYPE._serialized_start=283
  _PERMISSIONSTYPE._serialized_end=1417
  _PERMISSIONSTYPE_ALL._serialized_start=470
  _PERMISSIONSTYPE_ALL._serialized_end=475
  _PERMISSIONSTYPE_CACHESELECTOR._serialized_start=477
  _PERMISSIONSTYPE_CACHESELECTOR._serialized_end=522
  _PERMISSIONSTYPE_CACHEITEMSELECTOR._serialized_start=524
  _PERMISSIONSTYPE_CACHEITEMSELECTOR._serialized_end=588
  _PERMISSIONSTYPE_CACHEPERMISSIONS._serialized_start=591
  _PERMISSIONSTYPE_CACHEPERMISSIONS._serialized_end=964
  _PERMISSIONSTYPE_TOPICSELECTOR._serialized_start=966
  _PERMISSIONSTYPE_TOPICSELECTOR._serialized_end=1040
  _PERMISSIONSTYPE_TOPICPERMISSIONS._serialized_start=1043
  _PERMISSIONSTYPE_TOPICPERMISSIONS._serialized_end=1409
# @@protoc_insertion_point(module_scope)
