# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: extensions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x65xtensions.proto\x1a google/protobuf/descriptor.proto*0\n\rRetrySemantic\x12\x10\n\x0cNotRetryable\x10\x00\x12\r\n\tRetryable\x10\x01:I\n\x0eretry_semantic\x12\x1f.google.protobuf.MessageOptions\x18\xd0\x86\x03 \x01(\x0e\x32\x0e.RetrySemanticB_\n\x0fgrpc.extensionsZ0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x19Momento.Protos.Extensionsb\x06proto3')

_RETRYSEMANTIC = DESCRIPTOR.enum_types_by_name['RetrySemantic']
RetrySemantic = enum_type_wrapper.EnumTypeWrapper(_RETRYSEMANTIC)
NotRetryable = 0
Retryable = 1

RETRY_SEMANTIC_FIELD_NUMBER = 50000
retry_semantic = DESCRIPTOR.extensions_by_name['retry_semantic']

if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(retry_semantic)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017grpc.extensionsZ0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\031Momento.Protos.Extensions'
  _RETRYSEMANTIC._serialized_start=54
  _RETRYSEMANTIC._serialized_end=102
# @@protoc_insertion_point(module_scope)
