# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cacheclient.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63\x61\x63heclient.proto\x12\x0c\x63\x61\x63he_client\x1a\x0c\x63ommon.proto\" \n\x0b_GetRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\"_\n\x0c_GetResponse\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x12\x0f\n\x07message\x18\x03 \x01(\t\"<\n\x10_GetBatchRequest\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.cache_client._GetRequest\"#\n\x0e_DeleteRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\"\x11\n\x0f_DeleteResponse\"N\n\x0b_SetRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\"K\n\x0c_SetResponse\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\x0f\n\x07message\x18\x02 \x01(\t\"<\n\x10_SetBatchRequest\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.cache_client._SetRequest\"\xd9\x02\n\r_SetIfRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\"\n\x07present\x18\x04 \x01(\x0b\x32\x0f.common.PresentH\x00\x12;\n\x15present_and_not_equal\x18\x05 \x01(\x0b\x32\x1a.common.PresentAndNotEqualH\x00\x12 \n\x06\x61\x62sent\x18\x06 \x01(\x0b\x32\x0e.common.AbsentH\x00\x12\x1e\n\x05\x65qual\x18\x07 \x01(\x0b\x32\r.common.EqualH\x00\x12\x30\n\x0f\x61\x62sent_or_equal\x18\x08 \x01(\x0b\x32\x15.common.AbsentOrEqualH\x00\x12%\n\tnot_equal\x18\t \x01(\x0b\x32\x10.common.NotEqualH\x00\x42\x0b\n\tcondition\"\xaa\x01\n\x0e_SetIfResponse\x12\x36\n\x06stored\x18\x01 \x01(\x0b\x32$.cache_client._SetIfResponse._StoredH\x00\x12=\n\nnot_stored\x18\x02 \x01(\x0b\x32\'.cache_client._SetIfResponse._NotStoredH\x00\x1a\t\n\x07_Stored\x1a\x0c\n\n_NotStoredB\x08\n\x06result\"Y\n\x16_SetIfNotExistsRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\"\xc5\x01\n\x17_SetIfNotExistsResponse\x12?\n\x06stored\x18\x01 \x01(\x0b\x32-.cache_client._SetIfNotExistsResponse._StoredH\x00\x12\x46\n\nnot_stored\x18\x02 \x01(\x0b\x32\x30.cache_client._SetIfNotExistsResponse._NotStoredH\x00\x1a\t\n\x07_Stored\x1a\x0c\n\n_NotStoredB\x08\n\x06result\"\'\n\x11_KeysExistRequest\x12\x12\n\ncache_keys\x18\x01 \x03(\x0c\"$\n\x12_KeysExistResponse\x12\x0e\n\x06\x65xists\x18\x01 \x03(\x08\"P\n\x11_IncrementRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\"#\n\x12_IncrementResponse\x12\r\n\x05value\x18\x01 \x01(\x03\"\xa1\x01\n\x11_UpdateTtlRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\"\n\x18increase_to_milliseconds\x18\x02 \x01(\x04H\x00\x12\"\n\x18\x64\x65\x63rease_to_milliseconds\x18\x03 \x01(\x04H\x00\x12#\n\x19overwrite_to_milliseconds\x18\x04 \x01(\x04H\x00\x42\x0c\n\nupdate_ttl\"\xee\x01\n\x12_UpdateTtlResponse\x12\x34\n\x03set\x18\x01 \x01(\x0b\x32%.cache_client._UpdateTtlResponse._SetH\x00\x12;\n\x07not_set\x18\x02 \x01(\x0b\x32(.cache_client._UpdateTtlResponse._NotSetH\x00\x12<\n\x07missing\x18\x03 \x01(\x0b\x32).cache_client._UpdateTtlResponse._MissingH\x00\x1a\x06\n\x04_Set\x1a\t\n\x07_NotSet\x1a\n\n\x08_MissingB\x08\n\x06result\"\'\n\x12_ItemGetTtlRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\"\xcd\x01\n\x13_ItemGetTtlResponse\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.cache_client._ItemGetTtlResponse._FoundH\x00\x12=\n\x07missing\x18\x02 \x01(\x0b\x32*.cache_client._ItemGetTtlResponse._MissingH\x00\x1a&\n\x06_Found\x12\x1c\n\x14remaining_ttl_millis\x18\x01 \x01(\x04\x1a\n\n\x08_MissingB\x08\n\x06result\"(\n\x13_ItemGetTypeRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\"\xbd\x02\n\x14_ItemGetTypeResponse\x12:\n\x05\x66ound\x18\x01 \x01(\x0b\x32).cache_client._ItemGetTypeResponse._FoundH\x00\x12>\n\x07missing\x18\x02 \x01(\x0b\x32+.cache_client._ItemGetTypeResponse._MissingH\x00\x1aH\n\x06_Found\x12>\n\titem_type\x18\x01 \x01(\x0e\x32+.cache_client._ItemGetTypeResponse.ItemType\x1a\n\n\x08_Missing\"I\n\x08ItemType\x12\n\n\x06SCALAR\x10\x00\x12\x0e\n\nDICTIONARY\x10\x01\x12\x07\n\x03SET\x10\x02\x12\x08\n\x04LIST\x10\x03\x12\x0e\n\nSORTED_SET\x10\x04\x42\x08\n\x06result\"@\n\x15_DictionaryGetRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\x12\x0e\n\x06\x66ields\x18\x02 \x03(\x0c\"\xea\x02\n\x16_DictionaryGetResponse\x12<\n\x05\x66ound\x18\x01 \x01(\x0b\x32+.cache_client._DictionaryGetResponse._FoundH\x00\x12@\n\x07missing\x18\x02 \x01(\x0b\x32-.cache_client._DictionaryGetResponse._MissingH\x00\x1a\\\n\x1a_DictionaryGetResponsePart\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x1aX\n\x06_Found\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.cache_client._DictionaryGetResponse._DictionaryGetResponsePart\x1a\n\n\x08_MissingB\x0c\n\ndictionary\"2\n\x17_DictionaryFetchRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\"9\n\x19_DictionaryFieldValuePair\x12\r\n\x05\x66ield\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\"\xfa\x01\n\x18_DictionaryFetchResponse\x12>\n\x05\x66ound\x18\x01 \x01(\x0b\x32-.cache_client._DictionaryFetchResponse._FoundH\x00\x12\x42\n\x07missing\x18\x02 \x01(\x0b\x32/.cache_client._DictionaryFetchResponse._MissingH\x00\x1a@\n\x06_Found\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.cache_client._DictionaryFieldValuePair\x1a\n\n\x08_MissingB\x0c\n\ndictionary\"\x97\x01\n\x15_DictionarySetRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.cache_client._DictionaryFieldValuePair\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\"\x18\n\x16_DictionarySetResponse\"\x84\x01\n\x1b_DictionaryIncrementRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\x12\r\n\x05\x66ield\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\x12\x18\n\x10ttl_milliseconds\x18\x04 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x05 \x01(\x08\"-\n\x1c_DictionaryIncrementResponse\x12\r\n\x05value\x18\x01 \x01(\x03\"\xd4\x01\n\x18_DictionaryDeleteRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\x12;\n\x04some\x18\x02 \x01(\x0b\x32+.cache_client._DictionaryDeleteRequest.SomeH\x00\x12\x39\n\x03\x61ll\x18\x03 \x01(\x0b\x32*.cache_client._DictionaryDeleteRequest.AllH\x00\x1a\x16\n\x04Some\x12\x0e\n\x06\x66ields\x18\x01 \x03(\x0c\x1a\x05\n\x03\x41llB\x08\n\x06\x64\x65lete\"\x1b\n\x19_DictionaryDeleteResponse\"3\n\x18_DictionaryLengthRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\"\xd5\x01\n\x19_DictionaryLengthResponse\x12?\n\x05\x66ound\x18\x01 \x01(\x0b\x32..cache_client._DictionaryLengthResponse._FoundH\x00\x12\x43\n\x07missing\x18\x02 \x01(\x0b\x32\x30.cache_client._DictionaryLengthResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x0c\n\ndictionary\"$\n\x10_SetFetchRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\"\xb8\x01\n\x11_SetFetchResponse\x12\x37\n\x05\x66ound\x18\x01 \x01(\x0b\x32&.cache_client._SetFetchResponse._FoundH\x00\x12;\n\x07missing\x18\x02 \x01(\x0b\x32(.cache_client._SetFetchResponse._MissingH\x00\x1a\x1a\n\x06_Found\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\n\n\x08_MissingB\x05\n\x03set\"4\n\x11_SetSampleRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\r\n\x05limit\x18\x02 \x01(\x04\"\xbb\x01\n\x12_SetSampleResponse\x12\x38\n\x05\x66ound\x18\x01 \x01(\x0b\x32\'.cache_client._SetSampleResponse._FoundH\x00\x12<\n\x07missing\x18\x02 \x01(\x0b\x32).cache_client._SetSampleResponse._MissingH\x00\x1a\x1a\n\x06_Found\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\n\n\x08_MissingB\x05\n\x03set\"e\n\x10_SetUnionRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x10\n\x08\x65lements\x18\x02 \x03(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\"\x13\n\x11_SetUnionResponse\"\xba\x03\n\x15_SetDifferenceRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12?\n\x07minuend\x18\x02 \x01(\x0b\x32,.cache_client._SetDifferenceRequest._MinuendH\x00\x12\x45\n\nsubtrahend\x18\x03 \x01(\x0b\x32/.cache_client._SetDifferenceRequest._SubtrahendH\x00\x1a\x1c\n\x08_Minuend\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\xda\x01\n\x0b_Subtrahend\x12\x43\n\x03set\x18\x01 \x01(\x0b\x32\x34.cache_client._SetDifferenceRequest._Subtrahend._SetH\x00\x12M\n\x08identity\x18\x02 \x01(\x0b\x32\x39.cache_client._SetDifferenceRequest._Subtrahend._IdentityH\x00\x1a\x18\n\x04_Set\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\x0b\n\t_IdentityB\x10\n\x0esubtrahend_setB\x0c\n\ndifference\"\xb5\x01\n\x16_SetDifferenceResponse\x12<\n\x05\x66ound\x18\x01 \x01(\x0b\x32+.cache_client._SetDifferenceResponse._FoundH\x00\x12@\n\x07missing\x18\x02 \x01(\x0b\x32-.cache_client._SetDifferenceResponse._MissingH\x00\x1a\x08\n\x06_Found\x1a\n\n\x08_MissingB\x05\n\x03set\"9\n\x13_SetContainsRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x10\n\x08\x65lements\x18\x02 \x03(\x0c\"\xc1\x01\n\x14_SetContainsResponse\x12:\n\x05\x66ound\x18\x01 \x01(\x0b\x32).cache_client._SetContainsResponse._FoundH\x00\x12>\n\x07missing\x18\x02 \x01(\x0b\x32+.cache_client._SetContainsResponse._MissingH\x00\x1a\x1a\n\x06_Found\x12\x10\n\x08\x63ontains\x18\x01 \x03(\x08\x1a\n\n\x08_MissingB\x05\n\x03set\"%\n\x11_SetLengthRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\"\xb9\x01\n\x12_SetLengthResponse\x12\x38\n\x05\x66ound\x18\x01 \x01(\x0b\x32\'.cache_client._SetLengthResponse._FoundH\x00\x12<\n\x07missing\x18\x02 \x01(\x0b\x32).cache_client._SetLengthResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x05\n\x03set\"1\n\x0e_SetPopRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xb2\x01\n\x0f_SetPopResponse\x12\x35\n\x05\x66ound\x18\x01 \x01(\x0b\x32$.cache_client._SetPopResponse._FoundH\x00\x12\x39\n\x07missing\x18\x02 \x01(\x0b\x32&.cache_client._SetPopResponse._MissingH\x00\x1a\x1a\n\x06_Found\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\n\n\x08_MissingB\x05\n\x03set\"\x8f\x01\n\x1c_ListConcatenateFrontRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12\x0e\n\x06values\x18\x02 \x03(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\x12\x1d\n\x15truncate_back_to_size\x18\x05 \x01(\r\"4\n\x1d_ListConcatenateFrontResponse\x12\x13\n\x0blist_length\x18\x01 \x01(\r\"\x8f\x01\n\x1b_ListConcatenateBackRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12\x0e\n\x06values\x18\x02 \x03(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\x12\x1e\n\x16truncate_front_to_size\x18\x05 \x01(\r\"3\n\x1c_ListConcatenateBackResponse\x12\x13\n\x0blist_length\x18\x01 \x01(\r\"\x87\x01\n\x15_ListPushFrontRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\x12\x1d\n\x15truncate_back_to_size\x18\x05 \x01(\r\"-\n\x16_ListPushFrontResponse\x12\x13\n\x0blist_length\x18\x01 \x01(\r\"\x87\x01\n\x14_ListPushBackRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\x12\x1e\n\x16truncate_front_to_size\x18\x05 \x01(\r\",\n\x15_ListPushBackResponse\x12\x13\n\x0blist_length\x18\x01 \x01(\r\")\n\x14_ListPopFrontRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\"\xd7\x01\n\x15_ListPopFrontResponse\x12;\n\x05\x66ound\x18\x01 \x01(\x0b\x32*.cache_client._ListPopFrontResponse._FoundH\x00\x12?\n\x07missing\x18\x02 \x01(\x0b\x32,.cache_client._ListPopFrontResponse._MissingH\x00\x1a,\n\x06_Found\x12\r\n\x05\x66ront\x18\x01 \x01(\x0c\x12\x13\n\x0blist_length\x18\x02 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"(\n\x13_ListPopBackRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\"\xd3\x01\n\x14_ListPopBackResponse\x12:\n\x05\x66ound\x18\x01 \x01(\x0b\x32).cache_client._ListPopBackResponse._FoundH\x00\x12>\n\x07missing\x18\x02 \x01(\x0b\x32+.cache_client._ListPopBackResponse._MissingH\x00\x1a+\n\x06_Found\x12\x0c\n\x04\x62\x61\x63k\x18\x01 \x01(\x0c\x12\x13\n\x0blist_length\x18\x02 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"0\n\n_ListRange\x12\x13\n\x0b\x62\x65gin_index\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xe2\x01\n\x11_ListEraseRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12;\n\x04some\x18\x02 \x01(\x0b\x32+.cache_client._ListEraseRequest._ListRangesH\x00\x12\x33\n\x03\x61ll\x18\x03 \x01(\x0b\x32$.cache_client._ListEraseRequest._AllH\x00\x1a\x06\n\x04_All\x1a\x37\n\x0b_ListRanges\x12(\n\x06ranges\x18\x01 \x03(\x0b\x32\x18.cache_client._ListRangeB\x07\n\x05\x65rase\"\xbf\x01\n\x12_ListEraseResponse\x12\x38\n\x05\x66ound\x18\x01 \x01(\x0b\x32\'.cache_client._ListEraseResponse._FoundH\x00\x12<\n\x07missing\x18\x02 \x01(\x0b\x32).cache_client._ListEraseResponse._MissingH\x00\x1a\x1d\n\x06_Found\x12\x13\n\x0blist_length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"T\n\x12_ListRemoveRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12!\n\x17\x61ll_elements_with_value\x18\x02 \x01(\x0cH\x00\x42\x08\n\x06remove\"\xc2\x01\n\x13_ListRemoveResponse\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.cache_client._ListRemoveResponse._FoundH\x00\x12=\n\x07missing\x18\x02 \x01(\x0b\x32*.cache_client._ListRemoveResponse._MissingH\x00\x1a\x1d\n\x06_Found\x12\x13\n\x0blist_length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"\xd2\x01\n\x11_ListFetchRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12-\n\x0funbounded_start\x18\x02 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12\x19\n\x0finclusive_start\x18\x03 \x01(\x11H\x00\x12+\n\runbounded_end\x18\x04 \x01(\x0b\x32\x12.common._UnboundedH\x01\x12\x17\n\rexclusive_end\x18\x05 \x01(\x11H\x01\x42\r\n\x0bstart_indexB\x0b\n\tend_index\"\x82\x02\n\x12_ListRetainRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12-\n\x0funbounded_start\x18\x02 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12\x19\n\x0finclusive_start\x18\x03 \x01(\x11H\x00\x12+\n\runbounded_end\x18\x04 \x01(\x0b\x32\x12.common._UnboundedH\x01\x12\x17\n\rexclusive_end\x18\x05 \x01(\x11H\x01\x12\x18\n\x10ttl_milliseconds\x18\x06 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x07 \x01(\x08\x42\r\n\x0bstart_indexB\x0b\n\tend_index\"\xc2\x01\n\x13_ListRetainResponse\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.cache_client._ListRetainResponse._FoundH\x00\x12=\n\x07missing\x18\x02 \x01(\x0b\x32*.cache_client._ListRetainResponse._MissingH\x00\x1a\x1d\n\x06_Found\x12\x13\n\x0blist_length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"\xba\x01\n\x12_ListFetchResponse\x12\x38\n\x05\x66ound\x18\x01 \x01(\x0b\x32\'.cache_client._ListFetchResponse._FoundH\x00\x12<\n\x07missing\x18\x02 \x01(\x0b\x32).cache_client._ListFetchResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06values\x18\x01 \x03(\x0c\x1a\n\n\x08_MissingB\x06\n\x04list\"\'\n\x12_ListLengthRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\"\xbd\x01\n\x13_ListLengthResponse\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.cache_client._ListLengthResponse._FoundH\x00\x12=\n\x07missing\x18\x02 \x01(\x0b\x32*.cache_client._ListLengthResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"1\n\x11_SortedSetElement\x12\r\n\x05value\x18\x01 \x01(\x0c\x12\r\n\x05score\x18\x02 \x01(\x01\"\x8a\x01\n\x14_SortedSetPutRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x31\n\x08\x65lements\x18\x02 \x03(\x0b\x32\x1f.cache_client._SortedSetElement\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\"\x17\n\x15_SortedSetPutResponse\"\xc0\x06\n\x16_SortedSetFetchRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x39\n\x05order\x18\x02 \x01(\x0e\x32*.cache_client._SortedSetFetchRequest.Order\x12\x13\n\x0bwith_scores\x18\x03 \x01(\x08\x12\x41\n\x08\x62y_index\x18\x04 \x01(\x0b\x32-.cache_client._SortedSetFetchRequest._ByIndexH\x00\x12\x41\n\x08\x62y_score\x18\x05 \x01(\x0b\x32-.cache_client._SortedSetFetchRequest._ByScoreH\x00\x1a\xb6\x01\n\x08_ByIndex\x12-\n\x0funbounded_start\x18\x01 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12\x1f\n\x15inclusive_start_index\x18\x02 \x01(\x11H\x00\x12+\n\runbounded_end\x18\x03 \x01(\x0b\x32\x12.common._UnboundedH\x01\x12\x1d\n\x13\x65xclusive_end_index\x18\x04 \x01(\x11H\x01\x42\x07\n\x05startB\x05\n\x03\x65nd\x1a\xd3\x02\n\x08_ByScore\x12+\n\runbounded_min\x18\x01 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12I\n\tmin_score\x18\x02 \x01(\x0b\x32\x34.cache_client._SortedSetFetchRequest._ByScore._ScoreH\x00\x12+\n\runbounded_max\x18\x03 \x01(\x0b\x32\x12.common._UnboundedH\x01\x12I\n\tmax_score\x18\x04 \x01(\x0b\x32\x34.cache_client._SortedSetFetchRequest._ByScore._ScoreH\x01\x12\x0e\n\x06offset\x18\x05 \x01(\r\x12\r\n\x05\x63ount\x18\x06 \x01(\x11\x1a*\n\x06_Score\x12\r\n\x05score\x18\x01 \x01(\x01\x12\x11\n\texclusive\x18\x02 \x01(\x08\x42\x05\n\x03minB\x05\n\x03max\"&\n\x05Order\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\x42\x07\n\x05range\"\xd5\x03\n\x17_SortedSetFetchResponse\x12=\n\x05\x66ound\x18\x01 \x01(\x0b\x32,.cache_client._SortedSetFetchResponse._FoundH\x00\x12\x41\n\x07missing\x18\x02 \x01(\x0b\x32..cache_client._SortedSetFetchResponse._MissingH\x00\x1a\x9d\x02\n\x06_Found\x12\\\n\x12values_with_scores\x18\x01 \x01(\x0b\x32>.cache_client._SortedSetFetchResponse._Found._ValuesWithScoresH\x00\x12\x46\n\x06values\x18\x02 \x01(\x0b\x32\x34.cache_client._SortedSetFetchResponse._Found._ValuesH\x00\x1a\x46\n\x11_ValuesWithScores\x12\x31\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1f.cache_client._SortedSetElement\x1a\x19\n\x07_Values\x12\x0e\n\x06values\x18\x01 \x03(\x0c\x42\n\n\x08\x65lements\x1a\n\n\x08_MissingB\x0c\n\nsorted_set\"=\n\x19_SortedSetGetScoreRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x0e\n\x06values\x18\x02 \x03(\x0c\"\xa4\x03\n\x1a_SortedSetGetScoreResponse\x12I\n\x05\x66ound\x18\x01 \x01(\x0b\x32\x38.cache_client._SortedSetGetScoreResponse._SortedSetFoundH\x00\x12M\n\x07missing\x18\x02 \x01(\x0b\x32:.cache_client._SortedSetGetScoreResponse._SortedSetMissingH\x00\x1a[\n\x1e_SortedSetGetScoreResponsePart\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\r\n\x05score\x18\x02 \x01(\x01\x1al\n\x0f_SortedSetFound\x12Y\n\x08\x65lements\x18\x01 \x03(\x0b\x32G.cache_client._SortedSetGetScoreResponse._SortedSetGetScoreResponsePart\x1a\x13\n\x11_SortedSetMissingB\x0c\n\nsorted_set\"\xd7\x01\n\x17_SortedSetRemoveRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x39\n\x03\x61ll\x18\x02 \x01(\x0b\x32*.cache_client._SortedSetRemoveRequest._AllH\x00\x12;\n\x04some\x18\x03 \x01(\x0b\x32+.cache_client._SortedSetRemoveRequest._SomeH\x00\x1a\x06\n\x04_All\x1a\x17\n\x05_Some\x12\x0e\n\x06values\x18\x01 \x03(\x0c\x42\x11\n\x0fremove_elements\"\x1a\n\x18_SortedSetRemoveResponse\"|\n\x1a_SortedSetIncrementRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\x18\n\x10ttl_milliseconds\x18\x04 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x05 \x01(\x08\",\n\x1b_SortedSetIncrementResponse\x12\r\n\x05score\x18\x01 \x01(\x01\"\xa0\x01\n\x18_SortedSetGetRankRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12;\n\x05order\x18\x03 \x01(\x0e\x32,.cache_client._SortedSetGetRankRequest.Order\"&\n\x05Order\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\"\xa8\x02\n\x19_SortedSetGetRankResponse\x12Q\n\x0c\x65lement_rank\x18\x01 \x01(\x0b\x32\x39.cache_client._SortedSetGetRankResponse._RankResponsePartH\x00\x12L\n\x07missing\x18\x02 \x01(\x0b\x32\x39.cache_client._SortedSetGetRankResponse._SortedSetMissingH\x00\x1aM\n\x11_RankResponsePart\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\x0c\n\x04rank\x18\x02 \x01(\x04\x1a\x13\n\x11_SortedSetMissingB\x06\n\x04rank\"+\n\x17_SortedSetLengthRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\"\xd2\x01\n\x18_SortedSetLengthResponse\x12>\n\x05\x66ound\x18\x01 \x01(\x0b\x32-.cache_client._SortedSetLengthResponse._FoundH\x00\x12\x42\n\x07missing\x18\x02 \x01(\x0b\x32/.cache_client._SortedSetLengthResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x0c\n\nsorted_set\"\xfe\x01\n\x1e_SortedSetLengthByScoreRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x17\n\rinclusive_min\x18\x02 \x01(\x01H\x00\x12\x17\n\rexclusive_min\x18\x03 \x01(\x01H\x00\x12+\n\runbounded_min\x18\x04 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12\x17\n\rinclusive_max\x18\x05 \x01(\x01H\x01\x12\x17\n\rexclusive_max\x18\x06 \x01(\x01H\x01\x12+\n\runbounded_max\x18\x07 \x01(\x0b\x32\x12.common._UnboundedH\x01\x42\x05\n\x03minB\x05\n\x03max\"\xe7\x01\n\x1f_SortedSetLengthByScoreResponse\x12\x45\n\x05\x66ound\x18\x01 \x01(\x0b\x32\x34.cache_client._SortedSetLengthByScoreResponse._FoundH\x00\x12I\n\x07missing\x18\x02 \x01(\x0b\x32\x36.cache_client._SortedSetLengthByScoreResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x0c\n\nsorted_set*<\n\x0c\x45\x43\x61\x63heResult\x12\x0b\n\x07Invalid\x10\x00\x12\x06\n\x02Ok\x10\x01\x12\x07\n\x03Hit\x10\x02\x12\x08\n\x04Miss\x10\x03\"\x04\x08\x04\x10\x06\x32\xff\x1e\n\x03Scs\x12>\n\x03Get\x12\x19.cache_client._GetRequest\x1a\x1a.cache_client._GetResponse\"\x00\x12J\n\x08GetBatch\x12\x1e.cache_client._GetBatchRequest\x1a\x1a.cache_client._GetResponse\"\x00\x30\x01\x12>\n\x03Set\x12\x19.cache_client._SetRequest\x1a\x1a.cache_client._SetResponse\"\x00\x12J\n\x08SetBatch\x12\x1e.cache_client._SetBatchRequest\x1a\x1a.cache_client._SetResponse\"\x00\x30\x01\x12\x44\n\x05SetIf\x12\x1b.cache_client._SetIfRequest\x1a\x1c.cache_client._SetIfResponse\"\x00\x12\x62\n\x0eSetIfNotExists\x12$.cache_client._SetIfNotExistsRequest\x1a%.cache_client._SetIfNotExistsResponse\"\x03\x88\x02\x01\x12G\n\x06\x44\x65lete\x12\x1c.cache_client._DeleteRequest\x1a\x1d.cache_client._DeleteResponse\"\x00\x12P\n\tKeysExist\x12\x1f.cache_client._KeysExistRequest\x1a .cache_client._KeysExistResponse\"\x00\x12P\n\tIncrement\x12\x1f.cache_client._IncrementRequest\x1a .cache_client._IncrementResponse\"\x00\x12P\n\tUpdateTtl\x12\x1f.cache_client._UpdateTtlRequest\x1a .cache_client._UpdateTtlResponse\"\x00\x12S\n\nItemGetTtl\x12 .cache_client._ItemGetTtlRequest\x1a!.cache_client._ItemGetTtlResponse\"\x00\x12V\n\x0bItemGetType\x12!.cache_client._ItemGetTypeRequest\x1a\".cache_client._ItemGetTypeResponse\"\x00\x12\\\n\rDictionaryGet\x12#.cache_client._DictionaryGetRequest\x1a$.cache_client._DictionaryGetResponse\"\x00\x12\x62\n\x0f\x44ictionaryFetch\x12%.cache_client._DictionaryFetchRequest\x1a&.cache_client._DictionaryFetchResponse\"\x00\x12\\\n\rDictionarySet\x12#.cache_client._DictionarySetRequest\x1a$.cache_client._DictionarySetResponse\"\x00\x12n\n\x13\x44ictionaryIncrement\x12).cache_client._DictionaryIncrementRequest\x1a*.cache_client._DictionaryIncrementResponse\"\x00\x12\x65\n\x10\x44ictionaryDelete\x12&.cache_client._DictionaryDeleteRequest\x1a\'.cache_client._DictionaryDeleteResponse\"\x00\x12\x65\n\x10\x44ictionaryLength\x12&.cache_client._DictionaryLengthRequest\x1a\'.cache_client._DictionaryLengthResponse\"\x00\x12M\n\x08SetFetch\x12\x1e.cache_client._SetFetchRequest\x1a\x1f.cache_client._SetFetchResponse\"\x00\x12P\n\tSetSample\x12\x1f.cache_client._SetSampleRequest\x1a .cache_client._SetSampleResponse\"\x00\x12M\n\x08SetUnion\x12\x1e.cache_client._SetUnionRequest\x1a\x1f.cache_client._SetUnionResponse\"\x00\x12\\\n\rSetDifference\x12#.cache_client._SetDifferenceRequest\x1a$.cache_client._SetDifferenceResponse\"\x00\x12V\n\x0bSetContains\x12!.cache_client._SetContainsRequest\x1a\".cache_client._SetContainsResponse\"\x00\x12P\n\tSetLength\x12\x1f.cache_client._SetLengthRequest\x1a .cache_client._SetLengthResponse\"\x00\x12G\n\x06SetPop\x12\x1c.cache_client._SetPopRequest\x1a\x1d.cache_client._SetPopResponse\"\x00\x12\\\n\rListPushFront\x12#.cache_client._ListPushFrontRequest\x1a$.cache_client._ListPushFrontResponse\"\x00\x12Y\n\x0cListPushBack\x12\".cache_client._ListPushBackRequest\x1a#.cache_client._ListPushBackResponse\"\x00\x12Y\n\x0cListPopFront\x12\".cache_client._ListPopFrontRequest\x1a#.cache_client._ListPopFrontResponse\"\x00\x12V\n\x0bListPopBack\x12!.cache_client._ListPopBackRequest\x1a\".cache_client._ListPopBackResponse\"\x00\x12P\n\tListErase\x12\x1f.cache_client._ListEraseRequest\x1a .cache_client._ListEraseResponse\"\x00\x12S\n\nListRemove\x12 .cache_client._ListRemoveRequest\x1a!.cache_client._ListRemoveResponse\"\x00\x12P\n\tListFetch\x12\x1f.cache_client._ListFetchRequest\x1a .cache_client._ListFetchResponse\"\x00\x12S\n\nListLength\x12 .cache_client._ListLengthRequest\x1a!.cache_client._ListLengthResponse\"\x00\x12q\n\x14ListConcatenateFront\x12*.cache_client._ListConcatenateFrontRequest\x1a+.cache_client._ListConcatenateFrontResponse\"\x00\x12n\n\x13ListConcatenateBack\x12).cache_client._ListConcatenateBackRequest\x1a*.cache_client._ListConcatenateBackResponse\"\x00\x12S\n\nListRetain\x12 .cache_client._ListRetainRequest\x1a!.cache_client._ListRetainResponse\"\x00\x12Y\n\x0cSortedSetPut\x12\".cache_client._SortedSetPutRequest\x1a#.cache_client._SortedSetPutResponse\"\x00\x12_\n\x0eSortedSetFetch\x12$.cache_client._SortedSetFetchRequest\x1a%.cache_client._SortedSetFetchResponse\"\x00\x12h\n\x11SortedSetGetScore\x12\'.cache_client._SortedSetGetScoreRequest\x1a(.cache_client._SortedSetGetScoreResponse\"\x00\x12\x62\n\x0fSortedSetRemove\x12%.cache_client._SortedSetRemoveRequest\x1a&.cache_client._SortedSetRemoveResponse\"\x00\x12k\n\x12SortedSetIncrement\x12(.cache_client._SortedSetIncrementRequest\x1a).cache_client._SortedSetIncrementResponse\"\x00\x12\x65\n\x10SortedSetGetRank\x12&.cache_client._SortedSetGetRankRequest\x1a\'.cache_client._SortedSetGetRankResponse\"\x00\x12\x62\n\x0fSortedSetLength\x12%.cache_client._SortedSetLengthRequest\x1a&.cache_client._SortedSetLengthResponse\"\x00\x12w\n\x16SortedSetLengthByScore\x12,.cache_client._SortedSetLengthByScoreRequest\x1a-.cache_client._SortedSetLengthByScoreResponse\"\x00\x42\x64\n\x11grpc.cache_clientP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x1aMomento.Protos.CacheClientb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cacheclient_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021grpc.cache_clientP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\032Momento.Protos.CacheClient'
  _SCS.methods_by_name['SetIfNotExists']._options = None
  _SCS.methods_by_name['SetIfNotExists']._serialized_options = b'\210\002\001'
  _ECACHERESULT._serialized_start=12922
  _ECACHERESULT._serialized_end=12982
  __GETREQUEST._serialized_start=49
  __GETREQUEST._serialized_end=81
  __GETRESPONSE._serialized_start=83
  __GETRESPONSE._serialized_end=178
  __GETBATCHREQUEST._serialized_start=180
  __GETBATCHREQUEST._serialized_end=240
  __DELETEREQUEST._serialized_start=242
  __DELETEREQUEST._serialized_end=277
  __DELETERESPONSE._serialized_start=279
  __DELETERESPONSE._serialized_end=296
  __SETREQUEST._serialized_start=298
  __SETREQUEST._serialized_end=376
  __SETRESPONSE._serialized_start=378
  __SETRESPONSE._serialized_end=453
  __SETBATCHREQUEST._serialized_start=455
  __SETBATCHREQUEST._serialized_end=515
  __SETIFREQUEST._serialized_start=518
  __SETIFREQUEST._serialized_end=863
  __SETIFRESPONSE._serialized_start=866
  __SETIFRESPONSE._serialized_end=1036
  __SETIFRESPONSE__STORED._serialized_start=1003
  __SETIFRESPONSE__STORED._serialized_end=1012
  __SETIFRESPONSE__NOTSTORED._serialized_start=1014
  __SETIFRESPONSE__NOTSTORED._serialized_end=1026
  __SETIFNOTEXISTSREQUEST._serialized_start=1038
  __SETIFNOTEXISTSREQUEST._serialized_end=1127
  __SETIFNOTEXISTSRESPONSE._serialized_start=1130
  __SETIFNOTEXISTSRESPONSE._serialized_end=1327
  __SETIFNOTEXISTSRESPONSE__STORED._serialized_start=1003
  __SETIFNOTEXISTSRESPONSE__STORED._serialized_end=1012
  __SETIFNOTEXISTSRESPONSE__NOTSTORED._serialized_start=1014
  __SETIFNOTEXISTSRESPONSE__NOTSTORED._serialized_end=1026
  __KEYSEXISTREQUEST._serialized_start=1329
  __KEYSEXISTREQUEST._serialized_end=1368
  __KEYSEXISTRESPONSE._serialized_start=1370
  __KEYSEXISTRESPONSE._serialized_end=1406
  __INCREMENTREQUEST._serialized_start=1408
  __INCREMENTREQUEST._serialized_end=1488
  __INCREMENTRESPONSE._serialized_start=1490
  __INCREMENTRESPONSE._serialized_end=1525
  __UPDATETTLREQUEST._serialized_start=1528
  __UPDATETTLREQUEST._serialized_end=1689
  __UPDATETTLRESPONSE._serialized_start=1692
  __UPDATETTLRESPONSE._serialized_end=1930
  __UPDATETTLRESPONSE__SET._serialized_start=1891
  __UPDATETTLRESPONSE__SET._serialized_end=1897
  __UPDATETTLRESPONSE__NOTSET._serialized_start=1899
  __UPDATETTLRESPONSE__NOTSET._serialized_end=1908
  __UPDATETTLRESPONSE__MISSING._serialized_start=1910
  __UPDATETTLRESPONSE__MISSING._serialized_end=1920
  __ITEMGETTTLREQUEST._serialized_start=1932
  __ITEMGETTTLREQUEST._serialized_end=1971
  __ITEMGETTTLRESPONSE._serialized_start=1974
  __ITEMGETTTLRESPONSE._serialized_end=2179
  __ITEMGETTTLRESPONSE__FOUND._serialized_start=2119
  __ITEMGETTTLRESPONSE__FOUND._serialized_end=2157
  __ITEMGETTTLRESPONSE__MISSING._serialized_start=1910
  __ITEMGETTTLRESPONSE__MISSING._serialized_end=1920
  __ITEMGETTYPEREQUEST._serialized_start=2181
  __ITEMGETTYPEREQUEST._serialized_end=2221
  __ITEMGETTYPERESPONSE._serialized_start=2224
  __ITEMGETTYPERESPONSE._serialized_end=2541
  __ITEMGETTYPERESPONSE__FOUND._serialized_start=2372
  __ITEMGETTYPERESPONSE__FOUND._serialized_end=2444
  __ITEMGETTYPERESPONSE__MISSING._serialized_start=1910
  __ITEMGETTYPERESPONSE__MISSING._serialized_end=1920
  __ITEMGETTYPERESPONSE_ITEMTYPE._serialized_start=2458
  __ITEMGETTYPERESPONSE_ITEMTYPE._serialized_end=2531
  __DICTIONARYGETREQUEST._serialized_start=2543
  __DICTIONARYGETREQUEST._serialized_end=2607
  __DICTIONARYGETRESPONSE._serialized_start=2610
  __DICTIONARYGETRESPONSE._serialized_end=2972
  __DICTIONARYGETRESPONSE__DICTIONARYGETRESPONSEPART._serialized_start=2764
  __DICTIONARYGETRESPONSE__DICTIONARYGETRESPONSEPART._serialized_end=2856
  __DICTIONARYGETRESPONSE__FOUND._serialized_start=2858
  __DICTIONARYGETRESPONSE__FOUND._serialized_end=2946
  __DICTIONARYGETRESPONSE__MISSING._serialized_start=1910
  __DICTIONARYGETRESPONSE__MISSING._serialized_end=1920
  __DICTIONARYFETCHREQUEST._serialized_start=2974
  __DICTIONARYFETCHREQUEST._serialized_end=3024
  __DICTIONARYFIELDVALUEPAIR._serialized_start=3026
  __DICTIONARYFIELDVALUEPAIR._serialized_end=3083
  __DICTIONARYFETCHRESPONSE._serialized_start=3086
  __DICTIONARYFETCHRESPONSE._serialized_end=3336
  __DICTIONARYFETCHRESPONSE__FOUND._serialized_start=3246
  __DICTIONARYFETCHRESPONSE__FOUND._serialized_end=3310
  __DICTIONARYFETCHRESPONSE__MISSING._serialized_start=1910
  __DICTIONARYFETCHRESPONSE__MISSING._serialized_end=1920
  __DICTIONARYSETREQUEST._serialized_start=3339
  __DICTIONARYSETREQUEST._serialized_end=3490
  __DICTIONARYSETRESPONSE._serialized_start=3492
  __DICTIONARYSETRESPONSE._serialized_end=3516
  __DICTIONARYINCREMENTREQUEST._serialized_start=3519
  __DICTIONARYINCREMENTREQUEST._serialized_end=3651
  __DICTIONARYINCREMENTRESPONSE._serialized_start=3653
  __DICTIONARYINCREMENTRESPONSE._serialized_end=3698
  __DICTIONARYDELETEREQUEST._serialized_start=3701
  __DICTIONARYDELETEREQUEST._serialized_end=3913
  __DICTIONARYDELETEREQUEST_SOME._serialized_start=3874
  __DICTIONARYDELETEREQUEST_SOME._serialized_end=3896
  __DICTIONARYDELETEREQUEST_ALL._serialized_start=3898
  __DICTIONARYDELETEREQUEST_ALL._serialized_end=3903
  __DICTIONARYDELETERESPONSE._serialized_start=3915
  __DICTIONARYDELETERESPONSE._serialized_end=3942
  __DICTIONARYLENGTHREQUEST._serialized_start=3944
  __DICTIONARYLENGTHREQUEST._serialized_end=3995
  __DICTIONARYLENGTHRESPONSE._serialized_start=3998
  __DICTIONARYLENGTHRESPONSE._serialized_end=4211
  __DICTIONARYLENGTHRESPONSE__FOUND._serialized_start=4161
  __DICTIONARYLENGTHRESPONSE__FOUND._serialized_end=4185
  __DICTIONARYLENGTHRESPONSE__MISSING._serialized_start=1910
  __DICTIONARYLENGTHRESPONSE__MISSING._serialized_end=1920
  __SETFETCHREQUEST._serialized_start=4213
  __SETFETCHREQUEST._serialized_end=4249
  __SETFETCHRESPONSE._serialized_start=4252
  __SETFETCHRESPONSE._serialized_end=4436
  __SETFETCHRESPONSE__FOUND._serialized_start=4391
  __SETFETCHRESPONSE__FOUND._serialized_end=4417
  __SETFETCHRESPONSE__MISSING._serialized_start=1910
  __SETFETCHRESPONSE__MISSING._serialized_end=1920
  __SETSAMPLEREQUEST._serialized_start=4438
  __SETSAMPLEREQUEST._serialized_end=4490
  __SETSAMPLERESPONSE._serialized_start=4493
  __SETSAMPLERESPONSE._serialized_end=4680
  __SETSAMPLERESPONSE__FOUND._serialized_start=4391
  __SETSAMPLERESPONSE__FOUND._serialized_end=4417
  __SETSAMPLERESPONSE__MISSING._serialized_start=1910
  __SETSAMPLERESPONSE__MISSING._serialized_end=1920
  __SETUNIONREQUEST._serialized_start=4682
  __SETUNIONREQUEST._serialized_end=4783
  __SETUNIONRESPONSE._serialized_start=4785
  __SETUNIONRESPONSE._serialized_end=4804
  __SETDIFFERENCEREQUEST._serialized_start=4807
  __SETDIFFERENCEREQUEST._serialized_end=5249
  __SETDIFFERENCEREQUEST__MINUEND._serialized_start=4986
  __SETDIFFERENCEREQUEST__MINUEND._serialized_end=5014
  __SETDIFFERENCEREQUEST__SUBTRAHEND._serialized_start=5017
  __SETDIFFERENCEREQUEST__SUBTRAHEND._serialized_end=5235
  __SETDIFFERENCEREQUEST__SUBTRAHEND__SET._serialized_start=5180
  __SETDIFFERENCEREQUEST__SUBTRAHEND__SET._serialized_end=5204
  __SETDIFFERENCEREQUEST__SUBTRAHEND__IDENTITY._serialized_start=5206
  __SETDIFFERENCEREQUEST__SUBTRAHEND__IDENTITY._serialized_end=5217
  __SETDIFFERENCERESPONSE._serialized_start=5252
  __SETDIFFERENCERESPONSE._serialized_end=5433
  __SETDIFFERENCERESPONSE__FOUND._serialized_start=2119
  __SETDIFFERENCERESPONSE__FOUND._serialized_end=2127
  __SETDIFFERENCERESPONSE__MISSING._serialized_start=1910
  __SETDIFFERENCERESPONSE__MISSING._serialized_end=1920
  __SETCONTAINSREQUEST._serialized_start=5435
  __SETCONTAINSREQUEST._serialized_end=5492
  __SETCONTAINSRESPONSE._serialized_start=5495
  __SETCONTAINSRESPONSE._serialized_end=5688
  __SETCONTAINSRESPONSE__FOUND._serialized_start=5643
  __SETCONTAINSRESPONSE__FOUND._serialized_end=5669
  __SETCONTAINSRESPONSE__MISSING._serialized_start=1910
  __SETCONTAINSRESPONSE__MISSING._serialized_end=1920
  __SETLENGTHREQUEST._serialized_start=5690
  __SETLENGTHREQUEST._serialized_end=5727
  __SETLENGTHRESPONSE._serialized_start=5730
  __SETLENGTHRESPONSE._serialized_end=5915
  __SETLENGTHRESPONSE__FOUND._serialized_start=4161
  __SETLENGTHRESPONSE__FOUND._serialized_end=4185
  __SETLENGTHRESPONSE__MISSING._serialized_start=1910
  __SETLENGTHRESPONSE__MISSING._serialized_end=1920
  __SETPOPREQUEST._serialized_start=5917
  __SETPOPREQUEST._serialized_end=5966
  __SETPOPRESPONSE._serialized_start=5969
  __SETPOPRESPONSE._serialized_end=6147
  __SETPOPRESPONSE__FOUND._serialized_start=4391
  __SETPOPRESPONSE__FOUND._serialized_end=4417
  __SETPOPRESPONSE__MISSING._serialized_start=1910
  __SETPOPRESPONSE__MISSING._serialized_end=1920
  __LISTCONCATENATEFRONTREQUEST._serialized_start=6150
  __LISTCONCATENATEFRONTREQUEST._serialized_end=6293
  __LISTCONCATENATEFRONTRESPONSE._serialized_start=6295
  __LISTCONCATENATEFRONTRESPONSE._serialized_end=6347
  __LISTCONCATENATEBACKREQUEST._serialized_start=6350
  __LISTCONCATENATEBACKREQUEST._serialized_end=6493
  __LISTCONCATENATEBACKRESPONSE._serialized_start=6495
  __LISTCONCATENATEBACKRESPONSE._serialized_end=6546
  __LISTPUSHFRONTREQUEST._serialized_start=6549
  __LISTPUSHFRONTREQUEST._serialized_end=6684
  __LISTPUSHFRONTRESPONSE._serialized_start=6686
  __LISTPUSHFRONTRESPONSE._serialized_end=6731
  __LISTPUSHBACKREQUEST._serialized_start=6734
  __LISTPUSHBACKREQUEST._serialized_end=6869
  __LISTPUSHBACKRESPONSE._serialized_start=6871
  __LISTPUSHBACKRESPONSE._serialized_end=6915
  __LISTPOPFRONTREQUEST._serialized_start=6917
  __LISTPOPFRONTREQUEST._serialized_end=6958
  __LISTPOPFRONTRESPONSE._serialized_start=6961
  __LISTPOPFRONTRESPONSE._serialized_end=7176
  __LISTPOPFRONTRESPONSE__FOUND._serialized_start=7112
  __LISTPOPFRONTRESPONSE__FOUND._serialized_end=7156
  __LISTPOPFRONTRESPONSE__MISSING._serialized_start=1910
  __LISTPOPFRONTRESPONSE__MISSING._serialized_end=1920
  __LISTPOPBACKREQUEST._serialized_start=7178
  __LISTPOPBACKREQUEST._serialized_end=7218
  __LISTPOPBACKRESPONSE._serialized_start=7221
  __LISTPOPBACKRESPONSE._serialized_end=7432
  __LISTPOPBACKRESPONSE__FOUND._serialized_start=7369
  __LISTPOPBACKRESPONSE__FOUND._serialized_end=7412
  __LISTPOPBACKRESPONSE__MISSING._serialized_start=1910
  __LISTPOPBACKRESPONSE__MISSING._serialized_end=1920
  __LISTRANGE._serialized_start=7434
  __LISTRANGE._serialized_end=7482
  __LISTERASEREQUEST._serialized_start=7485
  __LISTERASEREQUEST._serialized_end=7711
  __LISTERASEREQUEST__ALL._serialized_start=7639
  __LISTERASEREQUEST__ALL._serialized_end=7645
  __LISTERASEREQUEST__LISTRANGES._serialized_start=7647
  __LISTERASEREQUEST__LISTRANGES._serialized_end=7702
  __LISTERASERESPONSE._serialized_start=7714
  __LISTERASERESPONSE._serialized_end=7905
  __LISTERASERESPONSE__FOUND._serialized_start=7856
  __LISTERASERESPONSE__FOUND._serialized_end=7885
  __LISTERASERESPONSE__MISSING._serialized_start=1910
  __LISTERASERESPONSE__MISSING._serialized_end=1920
  __LISTREMOVEREQUEST._serialized_start=7907
  __LISTREMOVEREQUEST._serialized_end=7991
  __LISTREMOVERESPONSE._serialized_start=7994
  __LISTREMOVERESPONSE._serialized_end=8188
  __LISTREMOVERESPONSE__FOUND._serialized_start=7856
  __LISTREMOVERESPONSE__FOUND._serialized_end=7885
  __LISTREMOVERESPONSE__MISSING._serialized_start=1910
  __LISTREMOVERESPONSE__MISSING._serialized_end=1920
  __LISTFETCHREQUEST._serialized_start=8191
  __LISTFETCHREQUEST._serialized_end=8401
  __LISTRETAINREQUEST._serialized_start=8404
  __LISTRETAINREQUEST._serialized_end=8662
  __LISTRETAINRESPONSE._serialized_start=8665
  __LISTRETAINRESPONSE._serialized_end=8859
  __LISTRETAINRESPONSE__FOUND._serialized_start=7856
  __LISTRETAINRESPONSE__FOUND._serialized_end=7885
  __LISTRETAINRESPONSE__MISSING._serialized_start=1910
  __LISTRETAINRESPONSE__MISSING._serialized_end=1920
  __LISTFETCHRESPONSE._serialized_start=8862
  __LISTFETCHRESPONSE._serialized_end=9048
  __LISTFETCHRESPONSE__FOUND._serialized_start=9004
  __LISTFETCHRESPONSE__FOUND._serialized_end=9028
  __LISTFETCHRESPONSE__MISSING._serialized_start=1910
  __LISTFETCHRESPONSE__MISSING._serialized_end=1920
  __LISTLENGTHREQUEST._serialized_start=9050
  __LISTLENGTHREQUEST._serialized_end=9089
  __LISTLENGTHRESPONSE._serialized_start=9092
  __LISTLENGTHRESPONSE._serialized_end=9281
  __LISTLENGTHRESPONSE__FOUND._serialized_start=4161
  __LISTLENGTHRESPONSE__FOUND._serialized_end=4185
  __LISTLENGTHRESPONSE__MISSING._serialized_start=1910
  __LISTLENGTHRESPONSE__MISSING._serialized_end=1920
  __SORTEDSETELEMENT._serialized_start=9283
  __SORTEDSETELEMENT._serialized_end=9332
  __SORTEDSETPUTREQUEST._serialized_start=9335
  __SORTEDSETPUTREQUEST._serialized_end=9473
  __SORTEDSETPUTRESPONSE._serialized_start=9475
  __SORTEDSETPUTRESPONSE._serialized_end=9498
  __SORTEDSETFETCHREQUEST._serialized_start=9501
  __SORTEDSETFETCHREQUEST._serialized_end=10333
  __SORTEDSETFETCHREQUEST__BYINDEX._serialized_start=9760
  __SORTEDSETFETCHREQUEST__BYINDEX._serialized_end=9942
  __SORTEDSETFETCHREQUEST__BYSCORE._serialized_start=9945
  __SORTEDSETFETCHREQUEST__BYSCORE._serialized_end=10284
  __SORTEDSETFETCHREQUEST__BYSCORE__SCORE._serialized_start=10228
  __SORTEDSETFETCHREQUEST__BYSCORE__SCORE._serialized_end=10270
  __SORTEDSETFETCHREQUEST_ORDER._serialized_start=10286
  __SORTEDSETFETCHREQUEST_ORDER._serialized_end=10324
  __SORTEDSETFETCHRESPONSE._serialized_start=10336
  __SORTEDSETFETCHRESPONSE._serialized_end=10805
  __SORTEDSETFETCHRESPONSE__FOUND._serialized_start=10494
  __SORTEDSETFETCHRESPONSE__FOUND._serialized_end=10779
  __SORTEDSETFETCHRESPONSE__FOUND__VALUESWITHSCORES._serialized_start=10670
  __SORTEDSETFETCHRESPONSE__FOUND__VALUESWITHSCORES._serialized_end=10740
  __SORTEDSETFETCHRESPONSE__FOUND__VALUES._serialized_start=10742
  __SORTEDSETFETCHRESPONSE__FOUND__VALUES._serialized_end=10767
  __SORTEDSETFETCHRESPONSE__MISSING._serialized_start=1910
  __SORTEDSETFETCHRESPONSE__MISSING._serialized_end=1920
  __SORTEDSETGETSCOREREQUEST._serialized_start=10807
  __SORTEDSETGETSCOREREQUEST._serialized_end=10868
  __SORTEDSETGETSCORERESPONSE._serialized_start=10871
  __SORTEDSETGETSCORERESPONSE._serialized_end=11291
  __SORTEDSETGETSCORERESPONSE__SORTEDSETGETSCORERESPONSEPART._serialized_start=11055
  __SORTEDSETGETSCORERESPONSE__SORTEDSETGETSCORERESPONSEPART._serialized_end=11146
  __SORTEDSETGETSCORERESPONSE__SORTEDSETFOUND._serialized_start=11148
  __SORTEDSETGETSCORERESPONSE__SORTEDSETFOUND._serialized_end=11256
  __SORTEDSETGETSCORERESPONSE__SORTEDSETMISSING._serialized_start=11258
  __SORTEDSETGETSCORERESPONSE__SORTEDSETMISSING._serialized_end=11277
  __SORTEDSETREMOVEREQUEST._serialized_start=11294
  __SORTEDSETREMOVEREQUEST._serialized_end=11509
  __SORTEDSETREMOVEREQUEST__ALL._serialized_start=7639
  __SORTEDSETREMOVEREQUEST__ALL._serialized_end=7645
  __SORTEDSETREMOVEREQUEST__SOME._serialized_start=11467
  __SORTEDSETREMOVEREQUEST__SOME._serialized_end=11490
  __SORTEDSETREMOVERESPONSE._serialized_start=11511
  __SORTEDSETREMOVERESPONSE._serialized_end=11537
  __SORTEDSETINCREMENTREQUEST._serialized_start=11539
  __SORTEDSETINCREMENTREQUEST._serialized_end=11663
  __SORTEDSETINCREMENTRESPONSE._serialized_start=11665
  __SORTEDSETINCREMENTRESPONSE._serialized_end=11709
  __SORTEDSETGETRANKREQUEST._serialized_start=11712
  __SORTEDSETGETRANKREQUEST._serialized_end=11872
  __SORTEDSETGETRANKREQUEST_ORDER._serialized_start=10286
  __SORTEDSETGETRANKREQUEST_ORDER._serialized_end=10324
  __SORTEDSETGETRANKRESPONSE._serialized_start=11875
  __SORTEDSETGETRANKRESPONSE._serialized_end=12171
  __SORTEDSETGETRANKRESPONSE__RANKRESPONSEPART._serialized_start=12065
  __SORTEDSETGETRANKRESPONSE__RANKRESPONSEPART._serialized_end=12142
  __SORTEDSETGETRANKRESPONSE__SORTEDSETMISSING._serialized_start=11258
  __SORTEDSETGETRANKRESPONSE__SORTEDSETMISSING._serialized_end=11277
  __SORTEDSETLENGTHREQUEST._serialized_start=12173
  __SORTEDSETLENGTHREQUEST._serialized_end=12216
  __SORTEDSETLENGTHRESPONSE._serialized_start=12219
  __SORTEDSETLENGTHRESPONSE._serialized_end=12429
  __SORTEDSETLENGTHRESPONSE__FOUND._serialized_start=4161
  __SORTEDSETLENGTHRESPONSE__FOUND._serialized_end=4185
  __SORTEDSETLENGTHRESPONSE__MISSING._serialized_start=1910
  __SORTEDSETLENGTHRESPONSE__MISSING._serialized_end=1920
  __SORTEDSETLENGTHBYSCOREREQUEST._serialized_start=12432
  __SORTEDSETLENGTHBYSCOREREQUEST._serialized_end=12686
  __SORTEDSETLENGTHBYSCORERESPONSE._serialized_start=12689
  __SORTEDSETLENGTHBYSCORERESPONSE._serialized_end=12920
  __SORTEDSETLENGTHBYSCORERESPONSE__FOUND._serialized_start=4161
  __SORTEDSETLENGTHBYSCORERESPONSE__FOUND._serialized_end=4185
  __SORTEDSETLENGTHBYSCORERESPONSE__MISSING._serialized_start=1910
  __SORTEDSETLENGTHBYSCORERESPONSE__MISSING._serialized_end=1920
  _SCS._serialized_start=12985
  _SCS._serialized_end=16952
# @@protoc_insertion_point(module_scope)
