# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vectorindex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11vectorindex.proto\x12\x0bvectorindex\"c\n\x05_Item\x12\n\n\x02id\x18\x01 \x01(\t\x12$\n\x06vector\x18\x02 \x01(\x0b\x32\x14.vectorindex._Vector\x12(\n\x08metadata\x18\x03 \x03(\x0b\x32\x16.vectorindex._Metadata\"P\n\x17_UpsertItemBatchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.vectorindex._Item\"1\n\x18_UpsertItemBatchResponse\x12\x15\n\rerror_indices\x18\x01 \x03(\r\"j\n\x17_DeleteItemBatchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\t\x12.\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\x1a\n\x18_DeleteItemBatchResponse\"\x1b\n\x07_Vector\x12\x10\n\x08\x65lements\x18\x01 \x03(\x02\"\xef\x01\n\t_Metadata\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x17\n\rinteger_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x17\n\rboolean_value\x18\x05 \x01(\x08H\x00\x12\x46\n\x15list_of_strings_value\x18\x06 \x01(\x0b\x32%.vectorindex._Metadata._ListOfStringsH\x00\x1a \n\x0e_ListOfStrings\x12\x0e\n\x06values\x18\x01 \x03(\tB\x07\n\x05value\"\x9f\x01\n\x10_MetadataRequest\x12\x32\n\x04some\x18\x02 \x01(\x0b\x32\".vectorindex._MetadataRequest.SomeH\x00\x12\x30\n\x03\x61ll\x18\x03 \x01(\x0b\x32!.vectorindex._MetadataRequest.AllH\x00\x1a\x16\n\x04Some\x12\x0e\n\x06\x66ields\x18\x01 \x03(\t\x1a\x05\n\x03\x41llB\x06\n\x04kind\"\x85\x01\n\x0e_AndExpression\x12\x38\n\x10\x66irst_expression\x18\x01 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\x12\x39\n\x11second_expression\x18\x02 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\x84\x01\n\r_OrExpression\x12\x38\n\x10\x66irst_expression\x18\x01 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\x12\x39\n\x11second_expression\x18\x02 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"N\n\x0e_NotExpression\x12<\n\x14\x65xpression_to_negate\x18\x01 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\x8c\x01\n\x11_EqualsExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x17\n\rinteger_value\x18\x03 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x04 \x01(\x02H\x00\x12\x17\n\rboolean_value\x18\x05 \x01(\x08H\x00\x42\x07\n\x05value\"`\n\x16_GreaterThanExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x42\x07\n\x05value\"g\n\x1d_GreaterThanOrEqualExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x42\x07\n\x05value\"]\n\x13_LessThanExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x42\x07\n\x05value\"d\n\x1a_LessThanOrEqualExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x42\x07\n\x05value\"I\n\x17_ListContainsExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x42\x07\n\x05value\"!\n\x12_IdInSetExpression\x12\x0b\n\x03ids\x18\x01 \x03(\t\"\xc0\x05\n\x11_FilterExpression\x12;\n\x11\x65quals_expression\x18\x01 \x01(\x0b\x32\x1e.vectorindex._EqualsExpressionH\x00\x12\x35\n\x0e\x61nd_expression\x18\x02 \x01(\x0b\x32\x1b.vectorindex._AndExpressionH\x00\x12\x33\n\ror_expression\x18\x03 \x01(\x0b\x32\x1a.vectorindex._OrExpressionH\x00\x12\x35\n\x0enot_expression\x18\x04 \x01(\x0b\x32\x1b.vectorindex._NotExpressionH\x00\x12\x46\n\x17greater_than_expression\x18\x05 \x01(\x0b\x32#.vectorindex._GreaterThanExpressionH\x00\x12V\n greater_than_or_equal_expression\x18\x06 \x01(\x0b\x32*.vectorindex._GreaterThanOrEqualExpressionH\x00\x12@\n\x14less_than_expression\x18\x07 \x01(\x0b\x32 .vectorindex._LessThanExpressionH\x00\x12P\n\x1dless_than_or_equal_expression\x18\x08 \x01(\x0b\x32\'.vectorindex._LessThanOrEqualExpressionH\x00\x12H\n\x18list_contains_expression\x18\t \x01(\x0b\x32$.vectorindex._ListContainsExpressionH\x00\x12?\n\x14id_in_set_expression\x18\n \x01(\x0b\x32\x1f.vectorindex._IdInSetExpressionH\x00\x42\x0c\n\nexpression\"\x13\n\x11_NoScoreThreshold\"\xad\x02\n\x0e_SearchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\r\n\x05top_k\x18\x02 \x01(\r\x12*\n\x0cquery_vector\x18\x03 \x01(\x0b\x32\x14.vectorindex._Vector\x12\x36\n\x0fmetadata_fields\x18\x04 \x01(\x0b\x32\x1d.vectorindex._MetadataRequest\x12\x19\n\x0fscore_threshold\x18\x05 \x01(\x02H\x00\x12<\n\x12no_score_threshold\x18\x06 \x01(\x0b\x32\x1e.vectorindex._NoScoreThresholdH\x00\x12.\n\x06\x66ilter\x18\x07 \x01(\x0b\x32\x1e.vectorindex._FilterExpressionB\x0b\n\tthreshold\"\xbc\x02\n\x1d_SearchAndFetchVectorsRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\r\n\x05top_k\x18\x02 \x01(\r\x12*\n\x0cquery_vector\x18\x03 \x01(\x0b\x32\x14.vectorindex._Vector\x12\x36\n\x0fmetadata_fields\x18\x04 \x01(\x0b\x32\x1d.vectorindex._MetadataRequest\x12\x19\n\x0fscore_threshold\x18\x05 \x01(\x02H\x00\x12<\n\x12no_score_threshold\x18\x06 \x01(\x0b\x32\x1e.vectorindex._NoScoreThresholdH\x00\x12.\n\x06\x66ilter\x18\x07 \x01(\x0b\x32\x1e.vectorindex._FilterExpressionB\x0b\n\tthreshold\"Q\n\n_SearchHit\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12(\n\x08metadata\x18\x03 \x03(\x0b\x32\x16.vectorindex._Metadata\"\x86\x01\n\x19_SearchAndFetchVectorsHit\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12(\n\x08metadata\x18\x03 \x03(\x0b\x32\x16.vectorindex._Metadata\x12$\n\x06vector\x18\x04 \x01(\x0b\x32\x14.vectorindex._Vector\"8\n\x0f_SearchResponse\x12%\n\x04hits\x18\x01 \x03(\x0b\x32\x17.vectorindex._SearchHit\"V\n\x1e_SearchAndFetchVectorsResponse\x12\x34\n\x04hits\x18\x01 \x03(\x0b\x32&.vectorindex._SearchAndFetchVectorsHit\"\xa7\x01\n\x1c_GetItemMetadataBatchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\t\x12\x36\n\x0fmetadata_fields\x18\x03 \x01(\x0b\x32\x1d.vectorindex._MetadataRequest\x12.\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\x92\x02\n\x15_ItemMetadataResponse\x12\x38\n\x04miss\x18\x01 \x01(\x0b\x32(.vectorindex._ItemMetadataResponse._MissH\x00\x12\x36\n\x03hit\x18\x02 \x01(\x0b\x32\'.vectorindex._ItemMetadataResponse._HitH\x00\x12\n\n\x02id\x18\x03 \x01(\t\x12(\n\x08metadata\x18\x04 \x03(\x0b\x32\x16.vectorindex._Metadata\x1a\x07\n\x05_Miss\x1a<\n\x04_Hit\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x08metadata\x18\x02 \x03(\x0b\x32\x16.vectorindex._MetadataB\n\n\x08response\"c\n\x1d_GetItemMetadataBatchResponse\x12\x42\n\x16item_metadata_response\x18\x01 \x03(\x0b\x32\".vectorindex._ItemMetadataResponse\"\x9f\x01\n\x14_GetItemBatchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\t\x12\x36\n\x0fmetadata_fields\x18\x03 \x01(\x0b\x32\x1d.vectorindex._MetadataRequest\x12.\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\xc6\x02\n\r_ItemResponse\x12\x30\n\x04miss\x18\x01 \x01(\x0b\x32 .vectorindex._ItemResponse._MissH\x00\x12.\n\x03hit\x18\x02 \x01(\x0b\x32\x1f.vectorindex._ItemResponse._HitH\x00\x12\n\n\x02id\x18\x03 \x01(\t\x12$\n\x06vector\x18\x04 \x01(\x0b\x32\x14.vectorindex._Vector\x12(\n\x08metadata\x18\x05 \x03(\x0b\x32\x16.vectorindex._Metadata\x1a\x07\n\x05_Miss\x1a\x62\n\x04_Hit\x12\n\n\x02id\x18\x01 \x01(\t\x12$\n\x06vector\x18\x02 \x01(\x0b\x32\x14.vectorindex._Vector\x12(\n\x08metadata\x18\x03 \x03(\x0b\x32\x16.vectorindex._MetadataB\n\n\x08response\"J\n\x15_GetItemBatchResponse\x12\x31\n\ritem_response\x18\x01 \x03(\x0b\x32\x1a.vectorindex._ItemResponse\"m\n\x12_CountItemsRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x32\n\x03\x61ll\x18\x02 \x01(\x0b\x32#.vectorindex._CountItemsRequest.AllH\x00\x1a\x05\n\x03\x41llB\x08\n\x06\x66ilter\")\n\x13_CountItemsResponse\x12\x12\n\nitem_count\x18\x01 \x01(\x04\x32\xa9\x05\n\x0bVectorIndex\x12`\n\x0fUpsertItemBatch\x12$.vectorindex._UpsertItemBatchRequest\x1a%.vectorindex._UpsertItemBatchResponse\"\x00\x12`\n\x0f\x44\x65leteItemBatch\x12$.vectorindex._DeleteItemBatchRequest\x1a%.vectorindex._DeleteItemBatchResponse\"\x00\x12\x45\n\x06Search\x12\x1b.vectorindex._SearchRequest\x1a\x1c.vectorindex._SearchResponse\"\x00\x12r\n\x15SearchAndFetchVectors\x12*.vectorindex._SearchAndFetchVectorsRequest\x1a+.vectorindex._SearchAndFetchVectorsResponse\"\x00\x12o\n\x14GetItemMetadataBatch\x12).vectorindex._GetItemMetadataBatchRequest\x1a*.vectorindex._GetItemMetadataBatchResponse\"\x00\x12W\n\x0cGetItemBatch\x12!.vectorindex._GetItemBatchRequest\x1a\".vectorindex._GetItemBatchResponse\"\x00\x12Q\n\nCountItems\x12\x1f.vectorindex._CountItemsRequest\x1a .vectorindex._CountItemsResponse\"\x00\x42\x63\n\x10grpc.vectorindexP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x1aMomento.Protos.VectorIndexb\x06proto3')



__ITEM = DESCRIPTOR.message_types_by_name['_Item']
__UPSERTITEMBATCHREQUEST = DESCRIPTOR.message_types_by_name['_UpsertItemBatchRequest']
__UPSERTITEMBATCHRESPONSE = DESCRIPTOR.message_types_by_name['_UpsertItemBatchResponse']
__DELETEITEMBATCHREQUEST = DESCRIPTOR.message_types_by_name['_DeleteItemBatchRequest']
__DELETEITEMBATCHRESPONSE = DESCRIPTOR.message_types_by_name['_DeleteItemBatchResponse']
__VECTOR = DESCRIPTOR.message_types_by_name['_Vector']
__METADATA = DESCRIPTOR.message_types_by_name['_Metadata']
__METADATA__LISTOFSTRINGS = __METADATA.nested_types_by_name['_ListOfStrings']
__METADATAREQUEST = DESCRIPTOR.message_types_by_name['_MetadataRequest']
__METADATAREQUEST_SOME = __METADATAREQUEST.nested_types_by_name['Some']
__METADATAREQUEST_ALL = __METADATAREQUEST.nested_types_by_name['All']
__ANDEXPRESSION = DESCRIPTOR.message_types_by_name['_AndExpression']
__OREXPRESSION = DESCRIPTOR.message_types_by_name['_OrExpression']
__NOTEXPRESSION = DESCRIPTOR.message_types_by_name['_NotExpression']
__EQUALSEXPRESSION = DESCRIPTOR.message_types_by_name['_EqualsExpression']
__GREATERTHANEXPRESSION = DESCRIPTOR.message_types_by_name['_GreaterThanExpression']
__GREATERTHANOREQUALEXPRESSION = DESCRIPTOR.message_types_by_name['_GreaterThanOrEqualExpression']
__LESSTHANEXPRESSION = DESCRIPTOR.message_types_by_name['_LessThanExpression']
__LESSTHANOREQUALEXPRESSION = DESCRIPTOR.message_types_by_name['_LessThanOrEqualExpression']
__LISTCONTAINSEXPRESSION = DESCRIPTOR.message_types_by_name['_ListContainsExpression']
__IDINSETEXPRESSION = DESCRIPTOR.message_types_by_name['_IdInSetExpression']
__FILTEREXPRESSION = DESCRIPTOR.message_types_by_name['_FilterExpression']
__NOSCORETHRESHOLD = DESCRIPTOR.message_types_by_name['_NoScoreThreshold']
__SEARCHREQUEST = DESCRIPTOR.message_types_by_name['_SearchRequest']
__SEARCHANDFETCHVECTORSREQUEST = DESCRIPTOR.message_types_by_name['_SearchAndFetchVectorsRequest']
__SEARCHHIT = DESCRIPTOR.message_types_by_name['_SearchHit']
__SEARCHANDFETCHVECTORSHIT = DESCRIPTOR.message_types_by_name['_SearchAndFetchVectorsHit']
__SEARCHRESPONSE = DESCRIPTOR.message_types_by_name['_SearchResponse']
__SEARCHANDFETCHVECTORSRESPONSE = DESCRIPTOR.message_types_by_name['_SearchAndFetchVectorsResponse']
__GETITEMMETADATABATCHREQUEST = DESCRIPTOR.message_types_by_name['_GetItemMetadataBatchRequest']
__ITEMMETADATARESPONSE = DESCRIPTOR.message_types_by_name['_ItemMetadataResponse']
__ITEMMETADATARESPONSE__MISS = __ITEMMETADATARESPONSE.nested_types_by_name['_Miss']
__ITEMMETADATARESPONSE__HIT = __ITEMMETADATARESPONSE.nested_types_by_name['_Hit']
__GETITEMMETADATABATCHRESPONSE = DESCRIPTOR.message_types_by_name['_GetItemMetadataBatchResponse']
__GETITEMBATCHREQUEST = DESCRIPTOR.message_types_by_name['_GetItemBatchRequest']
__ITEMRESPONSE = DESCRIPTOR.message_types_by_name['_ItemResponse']
__ITEMRESPONSE__MISS = __ITEMRESPONSE.nested_types_by_name['_Miss']
__ITEMRESPONSE__HIT = __ITEMRESPONSE.nested_types_by_name['_Hit']
__GETITEMBATCHRESPONSE = DESCRIPTOR.message_types_by_name['_GetItemBatchResponse']
__COUNTITEMSREQUEST = DESCRIPTOR.message_types_by_name['_CountItemsRequest']
__COUNTITEMSREQUEST_ALL = __COUNTITEMSREQUEST.nested_types_by_name['All']
__COUNTITEMSRESPONSE = DESCRIPTOR.message_types_by_name['_CountItemsResponse']
_Item = _reflection.GeneratedProtocolMessageType('_Item', (_message.Message,), {
  'DESCRIPTOR' : __ITEM,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._Item)
  })
_sym_db.RegisterMessage(_Item)

_UpsertItemBatchRequest = _reflection.GeneratedProtocolMessageType('_UpsertItemBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : __UPSERTITEMBATCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._UpsertItemBatchRequest)
  })
_sym_db.RegisterMessage(_UpsertItemBatchRequest)

_UpsertItemBatchResponse = _reflection.GeneratedProtocolMessageType('_UpsertItemBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : __UPSERTITEMBATCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._UpsertItemBatchResponse)
  })
_sym_db.RegisterMessage(_UpsertItemBatchResponse)

_DeleteItemBatchRequest = _reflection.GeneratedProtocolMessageType('_DeleteItemBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : __DELETEITEMBATCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._DeleteItemBatchRequest)
  })
_sym_db.RegisterMessage(_DeleteItemBatchRequest)

_DeleteItemBatchResponse = _reflection.GeneratedProtocolMessageType('_DeleteItemBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : __DELETEITEMBATCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._DeleteItemBatchResponse)
  })
_sym_db.RegisterMessage(_DeleteItemBatchResponse)

_Vector = _reflection.GeneratedProtocolMessageType('_Vector', (_message.Message,), {
  'DESCRIPTOR' : __VECTOR,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._Vector)
  })
_sym_db.RegisterMessage(_Vector)

_Metadata = _reflection.GeneratedProtocolMessageType('_Metadata', (_message.Message,), {

  '_ListOfStrings' : _reflection.GeneratedProtocolMessageType('_ListOfStrings', (_message.Message,), {
    'DESCRIPTOR' : __METADATA__LISTOFSTRINGS,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._Metadata._ListOfStrings)
    })
  ,
  'DESCRIPTOR' : __METADATA,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._Metadata)
  })
_sym_db.RegisterMessage(_Metadata)
_sym_db.RegisterMessage(_Metadata._ListOfStrings)

_MetadataRequest = _reflection.GeneratedProtocolMessageType('_MetadataRequest', (_message.Message,), {

  'Some' : _reflection.GeneratedProtocolMessageType('Some', (_message.Message,), {
    'DESCRIPTOR' : __METADATAREQUEST_SOME,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._MetadataRequest.Some)
    })
  ,

  'All' : _reflection.GeneratedProtocolMessageType('All', (_message.Message,), {
    'DESCRIPTOR' : __METADATAREQUEST_ALL,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._MetadataRequest.All)
    })
  ,
  'DESCRIPTOR' : __METADATAREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._MetadataRequest)
  })
_sym_db.RegisterMessage(_MetadataRequest)
_sym_db.RegisterMessage(_MetadataRequest.Some)
_sym_db.RegisterMessage(_MetadataRequest.All)

_AndExpression = _reflection.GeneratedProtocolMessageType('_AndExpression', (_message.Message,), {
  'DESCRIPTOR' : __ANDEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._AndExpression)
  })
_sym_db.RegisterMessage(_AndExpression)

_OrExpression = _reflection.GeneratedProtocolMessageType('_OrExpression', (_message.Message,), {
  'DESCRIPTOR' : __OREXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._OrExpression)
  })
_sym_db.RegisterMessage(_OrExpression)

_NotExpression = _reflection.GeneratedProtocolMessageType('_NotExpression', (_message.Message,), {
  'DESCRIPTOR' : __NOTEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._NotExpression)
  })
_sym_db.RegisterMessage(_NotExpression)

_EqualsExpression = _reflection.GeneratedProtocolMessageType('_EqualsExpression', (_message.Message,), {
  'DESCRIPTOR' : __EQUALSEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._EqualsExpression)
  })
_sym_db.RegisterMessage(_EqualsExpression)

_GreaterThanExpression = _reflection.GeneratedProtocolMessageType('_GreaterThanExpression', (_message.Message,), {
  'DESCRIPTOR' : __GREATERTHANEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GreaterThanExpression)
  })
_sym_db.RegisterMessage(_GreaterThanExpression)

_GreaterThanOrEqualExpression = _reflection.GeneratedProtocolMessageType('_GreaterThanOrEqualExpression', (_message.Message,), {
  'DESCRIPTOR' : __GREATERTHANOREQUALEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GreaterThanOrEqualExpression)
  })
_sym_db.RegisterMessage(_GreaterThanOrEqualExpression)

_LessThanExpression = _reflection.GeneratedProtocolMessageType('_LessThanExpression', (_message.Message,), {
  'DESCRIPTOR' : __LESSTHANEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._LessThanExpression)
  })
_sym_db.RegisterMessage(_LessThanExpression)

_LessThanOrEqualExpression = _reflection.GeneratedProtocolMessageType('_LessThanOrEqualExpression', (_message.Message,), {
  'DESCRIPTOR' : __LESSTHANOREQUALEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._LessThanOrEqualExpression)
  })
_sym_db.RegisterMessage(_LessThanOrEqualExpression)

_ListContainsExpression = _reflection.GeneratedProtocolMessageType('_ListContainsExpression', (_message.Message,), {
  'DESCRIPTOR' : __LISTCONTAINSEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._ListContainsExpression)
  })
_sym_db.RegisterMessage(_ListContainsExpression)

_IdInSetExpression = _reflection.GeneratedProtocolMessageType('_IdInSetExpression', (_message.Message,), {
  'DESCRIPTOR' : __IDINSETEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._IdInSetExpression)
  })
_sym_db.RegisterMessage(_IdInSetExpression)

_FilterExpression = _reflection.GeneratedProtocolMessageType('_FilterExpression', (_message.Message,), {
  'DESCRIPTOR' : __FILTEREXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._FilterExpression)
  })
_sym_db.RegisterMessage(_FilterExpression)

_NoScoreThreshold = _reflection.GeneratedProtocolMessageType('_NoScoreThreshold', (_message.Message,), {
  'DESCRIPTOR' : __NOSCORETHRESHOLD,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._NoScoreThreshold)
  })
_sym_db.RegisterMessage(_NoScoreThreshold)

_SearchRequest = _reflection.GeneratedProtocolMessageType('_SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchRequest)
  })
_sym_db.RegisterMessage(_SearchRequest)

_SearchAndFetchVectorsRequest = _reflection.GeneratedProtocolMessageType('_SearchAndFetchVectorsRequest', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHANDFETCHVECTORSREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchAndFetchVectorsRequest)
  })
_sym_db.RegisterMessage(_SearchAndFetchVectorsRequest)

_SearchHit = _reflection.GeneratedProtocolMessageType('_SearchHit', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHHIT,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchHit)
  })
_sym_db.RegisterMessage(_SearchHit)

_SearchAndFetchVectorsHit = _reflection.GeneratedProtocolMessageType('_SearchAndFetchVectorsHit', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHANDFETCHVECTORSHIT,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchAndFetchVectorsHit)
  })
_sym_db.RegisterMessage(_SearchAndFetchVectorsHit)

_SearchResponse = _reflection.GeneratedProtocolMessageType('_SearchResponse', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchResponse)
  })
_sym_db.RegisterMessage(_SearchResponse)

_SearchAndFetchVectorsResponse = _reflection.GeneratedProtocolMessageType('_SearchAndFetchVectorsResponse', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHANDFETCHVECTORSRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchAndFetchVectorsResponse)
  })
_sym_db.RegisterMessage(_SearchAndFetchVectorsResponse)

_GetItemMetadataBatchRequest = _reflection.GeneratedProtocolMessageType('_GetItemMetadataBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : __GETITEMMETADATABATCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GetItemMetadataBatchRequest)
  })
_sym_db.RegisterMessage(_GetItemMetadataBatchRequest)

_ItemMetadataResponse = _reflection.GeneratedProtocolMessageType('_ItemMetadataResponse', (_message.Message,), {

  '_Miss' : _reflection.GeneratedProtocolMessageType('_Miss', (_message.Message,), {
    'DESCRIPTOR' : __ITEMMETADATARESPONSE__MISS,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._ItemMetadataResponse._Miss)
    })
  ,

  '_Hit' : _reflection.GeneratedProtocolMessageType('_Hit', (_message.Message,), {
    'DESCRIPTOR' : __ITEMMETADATARESPONSE__HIT,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._ItemMetadataResponse._Hit)
    })
  ,
  'DESCRIPTOR' : __ITEMMETADATARESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._ItemMetadataResponse)
  })
_sym_db.RegisterMessage(_ItemMetadataResponse)
_sym_db.RegisterMessage(_ItemMetadataResponse._Miss)
_sym_db.RegisterMessage(_ItemMetadataResponse._Hit)

_GetItemMetadataBatchResponse = _reflection.GeneratedProtocolMessageType('_GetItemMetadataBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : __GETITEMMETADATABATCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GetItemMetadataBatchResponse)
  })
_sym_db.RegisterMessage(_GetItemMetadataBatchResponse)

_GetItemBatchRequest = _reflection.GeneratedProtocolMessageType('_GetItemBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : __GETITEMBATCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GetItemBatchRequest)
  })
_sym_db.RegisterMessage(_GetItemBatchRequest)

_ItemResponse = _reflection.GeneratedProtocolMessageType('_ItemResponse', (_message.Message,), {

  '_Miss' : _reflection.GeneratedProtocolMessageType('_Miss', (_message.Message,), {
    'DESCRIPTOR' : __ITEMRESPONSE__MISS,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._ItemResponse._Miss)
    })
  ,

  '_Hit' : _reflection.GeneratedProtocolMessageType('_Hit', (_message.Message,), {
    'DESCRIPTOR' : __ITEMRESPONSE__HIT,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._ItemResponse._Hit)
    })
  ,
  'DESCRIPTOR' : __ITEMRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._ItemResponse)
  })
_sym_db.RegisterMessage(_ItemResponse)
_sym_db.RegisterMessage(_ItemResponse._Miss)
_sym_db.RegisterMessage(_ItemResponse._Hit)

_GetItemBatchResponse = _reflection.GeneratedProtocolMessageType('_GetItemBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : __GETITEMBATCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GetItemBatchResponse)
  })
_sym_db.RegisterMessage(_GetItemBatchResponse)

_CountItemsRequest = _reflection.GeneratedProtocolMessageType('_CountItemsRequest', (_message.Message,), {

  'All' : _reflection.GeneratedProtocolMessageType('All', (_message.Message,), {
    'DESCRIPTOR' : __COUNTITEMSREQUEST_ALL,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._CountItemsRequest.All)
    })
  ,
  'DESCRIPTOR' : __COUNTITEMSREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._CountItemsRequest)
  })
_sym_db.RegisterMessage(_CountItemsRequest)
_sym_db.RegisterMessage(_CountItemsRequest.All)

_CountItemsResponse = _reflection.GeneratedProtocolMessageType('_CountItemsResponse', (_message.Message,), {
  'DESCRIPTOR' : __COUNTITEMSRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._CountItemsResponse)
  })
_sym_db.RegisterMessage(_CountItemsResponse)

_VECTORINDEX = DESCRIPTOR.services_by_name['VectorIndex']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020grpc.vectorindexP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\032Momento.Protos.VectorIndex'
  __ITEM._serialized_start=34
  __ITEM._serialized_end=133
  __UPSERTITEMBATCHREQUEST._serialized_start=135
  __UPSERTITEMBATCHREQUEST._serialized_end=215
  __UPSERTITEMBATCHRESPONSE._serialized_start=217
  __UPSERTITEMBATCHRESPONSE._serialized_end=266
  __DELETEITEMBATCHREQUEST._serialized_start=268
  __DELETEITEMBATCHREQUEST._serialized_end=374
  __DELETEITEMBATCHRESPONSE._serialized_start=376
  __DELETEITEMBATCHRESPONSE._serialized_end=402
  __VECTOR._serialized_start=404
  __VECTOR._serialized_end=431
  __METADATA._serialized_start=434
  __METADATA._serialized_end=673
  __METADATA__LISTOFSTRINGS._serialized_start=632
  __METADATA__LISTOFSTRINGS._serialized_end=664
  __METADATAREQUEST._serialized_start=676
  __METADATAREQUEST._serialized_end=835
  __METADATAREQUEST_SOME._serialized_start=798
  __METADATAREQUEST_SOME._serialized_end=820
  __METADATAREQUEST_ALL._serialized_start=822
  __METADATAREQUEST_ALL._serialized_end=827
  __ANDEXPRESSION._serialized_start=838
  __ANDEXPRESSION._serialized_end=971
  __OREXPRESSION._serialized_start=974
  __OREXPRESSION._serialized_end=1106
  __NOTEXPRESSION._serialized_start=1108
  __NOTEXPRESSION._serialized_end=1186
  __EQUALSEXPRESSION._serialized_start=1189
  __EQUALSEXPRESSION._serialized_end=1329
  __GREATERTHANEXPRESSION._serialized_start=1331
  __GREATERTHANEXPRESSION._serialized_end=1427
  __GREATERTHANOREQUALEXPRESSION._serialized_start=1429
  __GREATERTHANOREQUALEXPRESSION._serialized_end=1532
  __LESSTHANEXPRESSION._serialized_start=1534
  __LESSTHANEXPRESSION._serialized_end=1627
  __LESSTHANOREQUALEXPRESSION._serialized_start=1629
  __LESSTHANOREQUALEXPRESSION._serialized_end=1729
  __LISTCONTAINSEXPRESSION._serialized_start=1731
  __LISTCONTAINSEXPRESSION._serialized_end=1804
  __IDINSETEXPRESSION._serialized_start=1806
  __IDINSETEXPRESSION._serialized_end=1839
  __FILTEREXPRESSION._serialized_start=1842
  __FILTEREXPRESSION._serialized_end=2546
  __NOSCORETHRESHOLD._serialized_start=2548
  __NOSCORETHRESHOLD._serialized_end=2567
  __SEARCHREQUEST._serialized_start=2570
  __SEARCHREQUEST._serialized_end=2871
  __SEARCHANDFETCHVECTORSREQUEST._serialized_start=2874
  __SEARCHANDFETCHVECTORSREQUEST._serialized_end=3190
  __SEARCHHIT._serialized_start=3192
  __SEARCHHIT._serialized_end=3273
  __SEARCHANDFETCHVECTORSHIT._serialized_start=3276
  __SEARCHANDFETCHVECTORSHIT._serialized_end=3410
  __SEARCHRESPONSE._serialized_start=3412
  __SEARCHRESPONSE._serialized_end=3468
  __SEARCHANDFETCHVECTORSRESPONSE._serialized_start=3470
  __SEARCHANDFETCHVECTORSRESPONSE._serialized_end=3556
  __GETITEMMETADATABATCHREQUEST._serialized_start=3559
  __GETITEMMETADATABATCHREQUEST._serialized_end=3726
  __ITEMMETADATARESPONSE._serialized_start=3729
  __ITEMMETADATARESPONSE._serialized_end=4003
  __ITEMMETADATARESPONSE__MISS._serialized_start=3922
  __ITEMMETADATARESPONSE__MISS._serialized_end=3929
  __ITEMMETADATARESPONSE__HIT._serialized_start=3931
  __ITEMMETADATARESPONSE__HIT._serialized_end=3991
  __GETITEMMETADATABATCHRESPONSE._serialized_start=4005
  __GETITEMMETADATABATCHRESPONSE._serialized_end=4104
  __GETITEMBATCHREQUEST._serialized_start=4107
  __GETITEMBATCHREQUEST._serialized_end=4266
  __ITEMRESPONSE._serialized_start=4269
  __ITEMRESPONSE._serialized_end=4595
  __ITEMRESPONSE__MISS._serialized_start=3922
  __ITEMRESPONSE__MISS._serialized_end=3929
  __ITEMRESPONSE__HIT._serialized_start=4485
  __ITEMRESPONSE__HIT._serialized_end=4583
  __GETITEMBATCHRESPONSE._serialized_start=4597
  __GETITEMBATCHRESPONSE._serialized_end=4671
  __COUNTITEMSREQUEST._serialized_start=4673
  __COUNTITEMSREQUEST._serialized_end=4782
  __COUNTITEMSREQUEST_ALL._serialized_start=822
  __COUNTITEMSREQUEST_ALL._serialized_end=827
  __COUNTITEMSRESPONSE._serialized_start=4784
  __COUNTITEMSRESPONSE._serialized_end=4825
  _VECTORINDEX._serialized_start=4828
  _VECTORINDEX._serialized_end=5509
# @@protoc_insertion_point(module_scope)
