# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: controlclient.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ontrolclient.proto\x12\x0e\x63ontrol_client\")\n\x13_CreateStoreRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\x16\n\x14_CreateStoreResponse\")\n\x13_DeleteStoreRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteStoreResponse\"(\n\x12_ListStoresRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"P\n\x13_ListStoresResponse\x12%\n\x05store\x18\x01 \x03(\x0b\x32\x16.control_client._Store\x12\x12\n\nnext_token\x18\x02 \x01(\t\"\x1c\n\x06_Store\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\xda\x02\n\x11_SimilarityMetric\x12V\n\x14\x65uclidean_similarity\x18\x01 \x01(\x0b\x32\x36.control_client._SimilarityMetric._EuclideanSimilarityH\x00\x12H\n\rinner_product\x18\x02 \x01(\x0b\x32/.control_client._SimilarityMetric._InnerProductH\x00\x12P\n\x11\x63osine_similarity\x18\x03 \x01(\x0b\x32\x33.control_client._SimilarityMetric._CosineSimilarityH\x00\x1a\x16\n\x14_EuclideanSimilarity\x1a\x0f\n\r_InnerProduct\x1a\x13\n\x11_CosineSimilarityB\x13\n\x11similarity_metric\"\x7f\n\x13_CreateIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x16\n\x0enum_dimensions\x18\x02 \x01(\x04\x12<\n\x11similarity_metric\x18\x03 \x01(\x0b\x32!.control_client._SimilarityMetric\"\x16\n\x14_CreateIndexResponse\")\n\x13_DeleteIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteIndexResponse\"\x15\n\x13_ListIndexesRequest\"\xc8\x01\n\x14_ListIndexesResponse\x12<\n\x07indexes\x18\x01 \x03(\x0b\x32+.control_client._ListIndexesResponse._Index\x1ar\n\x06_Index\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x16\n\x0enum_dimensions\x18\x02 \x01(\x04\x12<\n\x11similarity_metric\x18\x03 \x01(\x0b\x32!.control_client._SimilarityMetric\")\n\x13_DeleteCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteCacheResponse\")\n\x13_CreateCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x16\n\x14_CreateCacheResponse\"(\n\x12_ListCachesRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"x\n\x0c_CacheLimits\x12\x18\n\x10max_traffic_rate\x18\x01 \x01(\r\x12\x1b\n\x13max_throughput_kbps\x18\x02 \x01(\r\x12\x18\n\x10max_item_size_kb\x18\x03 \x01(\r\x12\x17\n\x0fmax_ttl_seconds\x18\x04 \x01(\x04\"m\n\x0c_TopicLimits\x12\x18\n\x10max_publish_rate\x18\x01 \x01(\r\x12\x1e\n\x16max_subscription_count\x18\x02 \x01(\r\x12#\n\x1bmax_publish_message_size_kb\x18\x03 \x01(\r\"\x84\x01\n\x06_Cache\x12\x12\n\ncache_name\x18\x01 \x01(\t\x12\x32\n\x0c\x63\x61\x63he_limits\x18\x02 \x01(\x0b\x32\x1c.control_client._CacheLimits\x12\x32\n\x0ctopic_limits\x18\x03 \x01(\x0b\x32\x1c.control_client._TopicLimits\"P\n\x13_ListCachesResponse\x12%\n\x05\x63\x61\x63he\x18\x01 \x03(\x0b\x32\x16.control_client._Cache\x12\x12\n\nnext_token\x18\x02 \x01(\t\"/\n\x18_CreateSigningKeyRequest\x12\x13\n\x0bttl_minutes\x18\x01 \x01(\r\"<\n\x19_CreateSigningKeyResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nexpires_at\x18\x02 \x01(\x04\"*\n\x18_RevokeSigningKeyRequest\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x1b\n\x19_RevokeSigningKeyResponse\"1\n\x0b_SigningKey\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nexpires_at\x18\x02 \x01(\x04\"-\n\x17_ListSigningKeysRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"`\n\x18_ListSigningKeysResponse\x12\x30\n\x0bsigning_key\x18\x01 \x03(\x0b\x32\x1b.control_client._SigningKey\x12\x12\n\nnext_token\x18\x02 \x01(\t\"(\n\x12_FlushCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x15\n\x13_FlushCacheResponse2\xd9\t\n\nScsControl\x12Z\n\x0b\x43reateCache\x12#.control_client._CreateCacheRequest\x1a$.control_client._CreateCacheResponse\"\x00\x12Z\n\x0b\x44\x65leteCache\x12#.control_client._DeleteCacheRequest\x1a$.control_client._DeleteCacheResponse\"\x00\x12W\n\nListCaches\x12\".control_client._ListCachesRequest\x1a#.control_client._ListCachesResponse\"\x00\x12W\n\nFlushCache\x12\".control_client._FlushCacheRequest\x1a#.control_client._FlushCacheResponse\"\x00\x12i\n\x10\x43reateSigningKey\x12(.control_client._CreateSigningKeyRequest\x1a).control_client._CreateSigningKeyResponse\"\x00\x12i\n\x10RevokeSigningKey\x12(.control_client._RevokeSigningKeyRequest\x1a).control_client._RevokeSigningKeyResponse\"\x00\x12\x66\n\x0fListSigningKeys\x12\'.control_client._ListSigningKeysRequest\x1a(.control_client._ListSigningKeysResponse\"\x00\x12Z\n\x0b\x43reateIndex\x12#.control_client._CreateIndexRequest\x1a$.control_client._CreateIndexResponse\"\x00\x12Z\n\x0b\x44\x65leteIndex\x12#.control_client._DeleteIndexRequest\x1a$.control_client._DeleteIndexResponse\"\x00\x12Z\n\x0bListIndexes\x12#.control_client._ListIndexesRequest\x1a$.control_client._ListIndexesResponse\"\x00\x12Z\n\x0b\x43reateStore\x12#.control_client._CreateStoreRequest\x1a$.control_client._CreateStoreResponse\"\x00\x12Z\n\x0b\x44\x65leteStore\x12#.control_client._DeleteStoreRequest\x1a$.control_client._DeleteStoreResponse\"\x00\x12W\n\nListStores\x12\".control_client._ListStoresRequest\x1a#.control_client._ListStoresResponse\"\x00\x42h\n\x13grpc.control_clientP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x1cMomento.Protos.ControlClientb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'controlclient_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023grpc.control_clientP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\034Momento.Protos.ControlClient'
  __CREATESTOREREQUEST._serialized_start=39
  __CREATESTOREREQUEST._serialized_end=80
  __CREATESTORERESPONSE._serialized_start=82
  __CREATESTORERESPONSE._serialized_end=104
  __DELETESTOREREQUEST._serialized_start=106
  __DELETESTOREREQUEST._serialized_end=147
  __DELETESTORERESPONSE._serialized_start=149
  __DELETESTORERESPONSE._serialized_end=171
  __LISTSTORESREQUEST._serialized_start=173
  __LISTSTORESREQUEST._serialized_end=213
  __LISTSTORESRESPONSE._serialized_start=215
  __LISTSTORESRESPONSE._serialized_end=295
  __STORE._serialized_start=297
  __STORE._serialized_end=325
  __SIMILARITYMETRIC._serialized_start=328
  __SIMILARITYMETRIC._serialized_end=674
  __SIMILARITYMETRIC__EUCLIDEANSIMILARITY._serialized_start=593
  __SIMILARITYMETRIC__EUCLIDEANSIMILARITY._serialized_end=615
  __SIMILARITYMETRIC__INNERPRODUCT._serialized_start=617
  __SIMILARITYMETRIC__INNERPRODUCT._serialized_end=632
  __SIMILARITYMETRIC__COSINESIMILARITY._serialized_start=634
  __SIMILARITYMETRIC__COSINESIMILARITY._serialized_end=653
  __CREATEINDEXREQUEST._serialized_start=676
  __CREATEINDEXREQUEST._serialized_end=803
  __CREATEINDEXRESPONSE._serialized_start=805
  __CREATEINDEXRESPONSE._serialized_end=827
  __DELETEINDEXREQUEST._serialized_start=829
  __DELETEINDEXREQUEST._serialized_end=870
  __DELETEINDEXRESPONSE._serialized_start=872
  __DELETEINDEXRESPONSE._serialized_end=894
  __LISTINDEXESREQUEST._serialized_start=896
  __LISTINDEXESREQUEST._serialized_end=917
  __LISTINDEXESRESPONSE._serialized_start=920
  __LISTINDEXESRESPONSE._serialized_end=1120
  __LISTINDEXESRESPONSE__INDEX._serialized_start=1006
  __LISTINDEXESRESPONSE__INDEX._serialized_end=1120
  __DELETECACHEREQUEST._serialized_start=1122
  __DELETECACHEREQUEST._serialized_end=1163
  __DELETECACHERESPONSE._serialized_start=1165
  __DELETECACHERESPONSE._serialized_end=1187
  __CREATECACHEREQUEST._serialized_start=1189
  __CREATECACHEREQUEST._serialized_end=1230
  __CREATECACHERESPONSE._serialized_start=1232
  __CREATECACHERESPONSE._serialized_end=1254
  __LISTCACHESREQUEST._serialized_start=1256
  __LISTCACHESREQUEST._serialized_end=1296
  __CACHELIMITS._serialized_start=1298
  __CACHELIMITS._serialized_end=1418
  __TOPICLIMITS._serialized_start=1420
  __TOPICLIMITS._serialized_end=1529
  __CACHE._serialized_start=1532
  __CACHE._serialized_end=1664
  __LISTCACHESRESPONSE._serialized_start=1666
  __LISTCACHESRESPONSE._serialized_end=1746
  __CREATESIGNINGKEYREQUEST._serialized_start=1748
  __CREATESIGNINGKEYREQUEST._serialized_end=1795
  __CREATESIGNINGKEYRESPONSE._serialized_start=1797
  __CREATESIGNINGKEYRESPONSE._serialized_end=1857
  __REVOKESIGNINGKEYREQUEST._serialized_start=1859
  __REVOKESIGNINGKEYREQUEST._serialized_end=1901
  __REVOKESIGNINGKEYRESPONSE._serialized_start=1903
  __REVOKESIGNINGKEYRESPONSE._serialized_end=1930
  __SIGNINGKEY._serialized_start=1932
  __SIGNINGKEY._serialized_end=1981
  __LISTSIGNINGKEYSREQUEST._serialized_start=1983
  __LISTSIGNINGKEYSREQUEST._serialized_end=2028
  __LISTSIGNINGKEYSRESPONSE._serialized_start=2030
  __LISTSIGNINGKEYSRESPONSE._serialized_end=2126
  __FLUSHCACHEREQUEST._serialized_start=2128
  __FLUSHCACHEREQUEST._serialized_end=2168
  __FLUSHCACHERESPONSE._serialized_start=2170
  __FLUSHCACHERESPONSE._serialized_end=2191
  _SCSCONTROL._serialized_start=2194
  _SCSCONTROL._serialized_end=3435
# @@protoc_insertion_point(module_scope)
